% This file plots process of reallocation for natives and refugees 

% Source: '~/Dropbox/German Historical Data/Data files/Results from MZU'

close all

%% Data (from MZU Census data)
year = [1939, 1950, 1960, 1971];

ag_refugee = [0.1964	0.0821	0.04	0.024];
man_refugee = [0.43871	0.56928	0.56699	0.545669];

ag_native = [0.1395	0.11335	0.08833	0.0712];
man_native = [0.5129899	0.507626	0.50251	0.49346];

%% Figures

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Agriculture
%%%%%%%%%%%%%%%%%%%%%%%%%%%


Agfig = figure;

ref_plot = plot(year, ag_refugee);
hold on
ref_plot_points = plot(year, ag_refugee);
nat_plot = plot(year, ag_native);
nat_plot_points = plot(year, ag_native);
exp_line = line([1947 1947], [0 0.25]);
grid on
hold off


t1 = text(1948,0.23,'Expulsion','Interpreter','latex');
t2 = text(1958,0.11,'Natives','Interpreter','latex');
t3 = text(1963,0.015,'Refugees','Interpreter','latex');

ylim([0 0.25])
yticks([0 0.05 0.1 0.15 0.2 0.25])
xlim([1935 1975])
xticks([1939 1950 1960 1971])


set(ref_plot                        , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.orange    , ...
  'LineWidth'       , 4    );

set(nat_plot                        , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.blue    , ...
  'LineWidth'       , 4    );

set(ref_plot_points                        , ...
  'LineStyle'       , 'none'           , ...
  'Marker'          , 'o'           , ...
  'MarkerSize'      , 7             , ...
  'MarkerEdgeColor' , col.grey    , ...
  'MarkerFaceColor' , col.orange    );

set(nat_plot_points                        , ...
  'LineStyle'       , 'none'           , ...
  'Marker'          , 'o'           , ...
  'MarkerSize'      , 7             , ...
  'MarkerEdgeColor' , col.grey    , ...
  'MarkerFaceColor' , col.blue    );



set(exp_line                        , ...                          
  'LineStyle'       , '-'          , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 3            );


xlab = xlabel('Year','Interpreter','latex');
title('Agricultural Employment share','Interpreter','latex');


set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );

set( xlab                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );

set( [t1,t2, t3]                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );

print(Agfig,'-depsc',append(path_paper,"Figure3_cohort_lifecycle_ag.eps"))
print(Agfig,'-dpdf',append(path_paper,"Figure3_cohort_lifecycle_ag.pdf"))
	

%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Manufacturing
%%%%%%%%%%%%%%%%%%%%%%%%%%%


Manfig = figure;

ref_plot = plot(year, man_refugee);
hold on
ref_plot_points = plot(year, man_refugee);
nat_plot = plot(year, man_native);
nat_plot_points = plot(year, man_native);
exp_line = line([1947 1947], [0.4 0.65]);
hold off
grid on

t1 = text(1948,0.63,'Expulsion','Interpreter','latex');
t2 = text(1958,0.485,'Natives','Interpreter','latex');
t3 = text(1965,0.57,'Refugees','Interpreter','latex');



ylim([0.4 0.65])
yticks([0.4 0.45 0.5 0.55 0.6 0.65])
xlim([1935 1975])
xticks([1939 1950 1960 1971])


set(ref_plot                        , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.orange    , ...
  'LineWidth'       , 4    );

set(nat_plot                        , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.blue    , ...
  'LineWidth'       , 4    );

set(ref_plot_points                        , ...
  'LineStyle'       , 'none'           , ...
  'Marker'          , 'o'           , ...
  'MarkerSize'      , 7             , ...
  'MarkerEdgeColor' , col.grey    , ...
  'MarkerFaceColor' , col.orange    );

set(nat_plot_points                        , ...
  'LineStyle'       , 'none'           , ...
  'Marker'          , 'o'           , ...
  'MarkerSize'      , 7             , ...
  'MarkerEdgeColor' , col.grey    , ...
  'MarkerFaceColor' , col.blue    );

set(exp_line                        , ...                          
  'LineStyle'       , '-'          , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 3            );


set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );

set( [t1,t2, t3]                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );


xlab = xlabel('Year','Interpreter','latex');

set( xlab                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 18          );

title('Manufacturing Employment share','Interpreter','latex');

print(Manfig,'-depsc',append(path_paper,"Figure3_cohort_lifecycle_manufac.eps"))
print(Manfig,'-dpdf',append(path_paper,"Figure3_cohort_lifecycle_manufac.pdf"))


	
