% This file plots the time series of the OLS estimates of the refugee
% experiment



close all
crit_val = 1.96;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% MODEL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Read Estimated table from model
% scale_coeff = readtable(append(path_model_output,"scale_coefficients.csv"));
scale_coeff = readtable(append(path_model_output,"Figure4_scale_coefficients.csv"));



year = scale_coeff(:,1);
beta_y = scale_coeff(:,2);
sd_y = scale_coeff(:,4);
beta_pop = scale_coeff(:,3);
sd_pop = scale_coeff(:,5);

year = year{:,:};
beta_y = beta_y{:,:};
sd_y = sd_y{:,:};
beta_pop = beta_pop{:,:};
sd_pop = sd_pop{:,:};

filter = year <= 2000;
year = year(filter);
beta_y = beta_y(filter);
sd_y = sd_y(filter);
beta_pop = beta_pop(filter);
sd_pop = sd_pop(filter);

errbnd_model_low_y = beta_y - crit_val*sd_y;
errbnd_model_hi_y = beta_y + crit_val*sd_y;
errbnd_model_low_pop = beta_pop - crit_val*sd_pop;
errbnd_model_hi_pop = beta_pop + crit_val*sd_pop;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% DATA
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% GDP
year_base_y = [1950, 1957, 1961, 1964, 1966];
bhat_base_y = [-0.083, 0.368, 0.502 , 0.563, 0.524];
sd_base_y = [0.382, 0.208, 0.227, 0.211, 0.204];

year_late_y = [1970, 1972, 1974, 1980, 1992, 1994, 1996];
bhat_late_y = [0.453, 0.498, 0.456 , 0.201,   0.389, 0.306,   0.333 ];
sd_late_y = [0.180, 0.173, 0.171, 0.198 ,   0.194         ,  0.227         ,  0.262 ];

year_axis_y = [1948, 1957, 1961, 1964, 1966, 1970, 1972, 1974, 1980, 1990, 2000];
axis_line_y = zeros(size(year_axis_y));

errbnd_base_y = crit_val*sd_base_y;
errbnd_late_y = crit_val*sd_late_y;


% Population
year_base_pop = [1950, 1961];
bhat_base_pop = [1.225, 1.147];
sd_base_pop = [0.142, 0.257];

year_late_pop = [1970, 1972, 1974, 1980, 1992, 1994, 1996];
bhat_late_pop = [1.135, 1.119, 1.137 , 1.152,   1.046, 1.136,   1.220 ];
sd_late_pop = [0.242, 0.260, 0.263, 0.305 ,   0.329         ,  0.327         ,  0.351 ];


year_axis_pop = [1948, 1957, 1961, 1964, 1966, 1970, 1972, 1974, 1980, 1990, 2000];
axis_line_pop = zeros(size(year_axis_pop));

errbnd_base_pop = crit_val*sd_base_pop;
errbnd_late_pop = crit_val*sd_late_pop;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% FIGURES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

for j = 1:2 
    
    if j == 1
     year_base =  year_base_y;
     bhat_base =   bhat_base_y;
     errbnd_base = errbnd_base_y;
     year_late = year_late_y;
     bhat_late = bhat_late_y;
     errbnd_late =  errbnd_late_y;
     year_axis = year_axis_y;
     axis_line = axis_line_y;
     beta_model = beta_y;
     errbnd_model_low = errbnd_model_low_y;
     errbnd_model_hi = errbnd_model_hi_y;
     title_lab = '$\ln y_{rt} - \ln y_{r1935}  =  \beta_{t} \times \mu_{r1950} + $ controls $ + u_{rt}$';
     filename = append(path_paper,"Figure4_scale_effect_y");
    end
    
    if j == 2
     year_base =  year_base_pop;
     bhat_base =   bhat_base_pop;
     errbnd_base = errbnd_base_pop;
     year_late = year_late_pop;
     bhat_late = bhat_late_pop;
     errbnd_late = errbnd_late_pop;
     year_axis = year_axis_pop;
     axis_line = axis_line_pop;
     beta_model = beta_pop;
     errbnd_model_low = errbnd_model_low_pop;
     errbnd_model_hi = errbnd_model_hi_pop;
     title_lab = '$\ln L_{rt} - \ln L_{r1935}  =  \beta_{t} \times \mu_{r1950} + $ controls $ + u_{rt}$';
     filename = append(path_paper,"Figure4_scale_effect_pop"); 
        
    end


f_baseline = figure;

errorplot = errorbar(year_base,bhat_base,errbnd_base);
hold on
grid on
betaplot = plot(year_base,bhat_base);
errorplot_late = errorbar(year_late,bhat_late,errbnd_late);
betaplot_late = plot(year_late,bhat_late);
zeroline = plot(year_axis,axis_line);

betaplot_points = plot(year_base,bhat_base);
betaplot_late_points = plot(year_late,bhat_late);

model_plot = plot(year,beta_model);

year_fill_var = [year; flip(year)];
CI = fill(year_fill_var,[errbnd_model_low; flip(errbnd_model_hi)],col.blue);
alpha(.2);
hold off


set([betaplot, betaplot_late] , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.orange    , ...
  'LineWidth'       , 2.5          );

set([betaplot_points, betaplot_late_points]        , ...
  'LineStyle'       , 'none'           , ...
  'Marker'          , 'o'           , ...
  'MarkerSize'      , 8             , ...
  'MarkerEdgeColor' , col.grey    , ...
  'MarkerFaceColor' , col.orange    );


set([errorplot, errorplot_late] , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'o'           , ...
  'Color'           ,  col.grey    , ...
  'LineWidth'       , 1             , ...
  'MarkerSize'      , 7             , ...
  'MarkerEdgeColor' , [.2 .2 .2]    , ...
  'MarkerFaceColor' , [.7 .7 .7]    , ...
  'CapSize',12);

set([zeroline] , ...
  'LineStyle'       , '--'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 2.5     );

set([model_plot] , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.blue    , ...
  'LineWidth'       , 2.5          );

xlim([year_axis(1), year_axis(end)])
xticks([1950 1955 1960 1965 1970 1975 1980 1985 1990 1995 2000])

hXLabel = xlabel('Year','Interpreter','latex');
hYLabel = ylabel('$\beta_{t}$','Interpreter','latex','Rotation',0);
title(title_lab,'Interpreter','latex');

set(gca , 'FontName','Helvetica' ,'FontSize', 14);
set(hXLabel,'FontName','Helvetica','FontSize', 18);
set(hYLabel,'FontName','Helvetica','FontSize', 18);


lgd  = legend([betaplot,model_plot], 'Data','Model');
lgd.Interpreter = 'latex';
lgd.FontName = 'Helvetica';
lgd.FontSize = 16;
lgd.Location = 'southeast';
lgd.NumColumns = 1;


print(f_baseline,'-depsc',append(filename,".eps"));
print(f_baseline,'-dpdf',append(filename,".pdf"));


end



