

close all
%%% Load Data

% params = readtable(append(path_model_output,"id_parameters.csv"));
% moments = readtable(append(path_model_output,"id_moments.csv"));
% estimates = readtable(append(path_model_output,"id_estimated_parameters.csv"));

params = readtable(append(path_model_output,"FigureSM6_7_id_parameters.csv"));
moments = readtable(append(path_model_output,"FigureSM6_7_id_moments.csv"));
estimates = readtable(append(path_model_output,"FigureSM6_7_id_estimated_parameters.csv"));


params = params{:,:};
moments = moments{:,:};
estimates =  estimates{:,:};


for k = 1:4
    
    if k == 1
    xlab_txt = 'Knowledge elasticity $\lambda$';
    title_txt = 'Regression: $\ln y_{r1961} = \beta \mu_{r1950}^{R} + X_{r}\gamma + u_{r}$';
    fig_name = 'FigureSM6_lambda';    
    end
    
    if k == 2
    xlab_txt = 'Elasticity of substitution $\rho$';
    title_txt = 'Regression: $\ln y_{r1950} = \beta \mu_{r1950}^{R} + X_{r}\gamma + u_{r}$';
    fig_name = 'FigureSM6_rho';    
    end
    
    if k == 3
    xlab_txt = 'Frequency of mobility shock $\psi$';
    title_txt = 'Regression: $\mu_{r1961} = \delta_{S} + \beta \mu_{r1950}^{R} + u_{r}$';
    fig_name = 'FigureSM6_psi';    
    end
    
    if k == 4
    xlab_txt = 'Labor supply elasticity $\varepsilon$';
    title_txt = 'Regression: $\ln l_{r1955} - \ln l_{r1950}  = \beta \mu_{r1950}^{R} + X_{r}\gamma + u_{r}$';
    fig_name = 'FigureSM6_epsilon';    
    end


fig_id = figure();
idplot = plot(params(:,k),moments(:,k));
hold on 
est_plot = line([estimates(k) estimates(k)], [min(moments(:,k)) max(moments(:,k))]);
hold off

grid on

set(idplot                        , ...
  'LineStyle'       , '-'           , ...
  'Marker'          , 'o'           , ...
  'Color'           , col.blue    , ...
  'LineWidth'       , 4            , ... 
  'MarkerSize'      , 6             , ...
  'MarkerEdgeColor' , col.blue    , ...
  'MarkerFaceColor' , col.blue    );

set(est_plot                        , ...
  'LineStyle'       , '--'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.orange    , ...
  'LineWidth'       , 4             );

xlab = xlabel(xlab_txt,'Interpreter','latex');
ylab = ylabel('$\hat{\beta}$','Interpreter','latex');
Fig_title = title(title_txt,'Interpreter','latex');

set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 14          );

set( xlab                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 14          );

set( ylab                       , ...
    'rotation'   , 0  ); 



print(fig_id,'-depsc',append(path_appendix,fig_name));
print(fig_id,'-dpdf',append(path_appendix,fig_name));


end



 
