

%%% Load Data

% SpatialDisperion = readtable(append(path_model_output,"refugees_spatial_dynamics_longrun.csv"));

SpatialDisperion = readtable(append(path_model_output,"FigureSM8_spatial_disperion_baseline.csv"));

NumSim = (size(SpatialDisperion,2)-1)/3;

time = SpatialDisperion(2:(end-1),1);
ref_disp = SpatialDisperion(2:(end-1),[2:3:(1+NumSim*3)]);
y_gr_disp = SpatialDisperion(2:(end-1),[3:3:(2+NumSim*3)]);
pop_gr_disp = SpatialDisperion(2:(end-1),[4:3:(3+NumSim*3)]);

time = time{:,:};
ref_disp = ref_disp{:,:};
y_gr_disp = y_gr_disp{:,:};
pop_gr_disp = pop_gr_disp{:,:};

time = time + 1932;

close all

%% Spatial dispersion in refugee share
ref_disp_fig = figure;
refplot = plot(time,ref_disp,'LineWidth', 3);

hold on
exp_line = plot([1947 1947], [0, 1.2*max(max(ref_disp))]);
shock_line = plot([1970 1970], [0, 1.2*max(max(ref_disp))]);

t1 = text(1933,1.21*max(max(ref_disp)) ,'Expulsion','Interpreter','latex');
t2 = text(1965,1.21*max(max(ref_disp)) ,'$\mathcal{Q}_{rt} = \mathcal{Q}_{r}$','Interpreter','latex');

xlim([1920 inf])
ylim([0, 1.4*max(max(ref_disp))])

grid on
hold off

grid on
hold off

title('Spatial disperion in refugee share','Interpreter','latex');
xlabel('Year','Interpreter','latex');

set([exp_line, shock_line] , ...
  'LineStyle'       , '--'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 2.5          );

set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 16          );

print(ref_disp_fig,'-depsc',append(path_appendix,"FigureSM8_dispersion_refshare.eps"));
print(ref_disp_fig,'-dpdf',append(path_appendix,"FigureSM8_dispersion_refshare.pdf"));


%% Spatial dispersion in income growth 
y_disp_fig = figure;
yplot = plot(time(1:120),y_gr_disp(1:120,:),'LineWidth', 3);


hold on
exp_line = plot([1947 1947], [0, 1.2*max(max(y_gr_disp))]);
shock_line = plot([1970 1970], [0, 1.2*max(max(y_gr_disp))]);

t1 = text(1933,1.21*max(max(y_gr_disp)) ,'Expulsion','Interpreter','latex');
t2 = text(1965,1.21*max(max(y_gr_disp)) ,'$\mathcal{Q}_{rt} = \mathcal{Q}_{r}$','Interpreter','latex');


xlim([1920 inf])
ylim([0, 1.4*max(max(y_gr_disp))])
grid on
hold off

title('Spatial disperion in annual income growth','Interpreter','latex');
xlabel('Year','Interpreter','latex');

set([exp_line, shock_line] , ...
  'LineStyle'       , '--'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 2.5          );

set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 16          );

print(y_disp_fig,'-depsc',append(path_appendix,"FigureSM8_dispersion_ygrowth.eps"));
print(y_disp_fig,'-dpdf',append(path_appendix,"FigureSM8_dispersion_ygrowth.pdf"));


%% Spatial dispersion in population growth 
pop_disp_fig = figure;
popplot = plot(time(1:120),pop_gr_disp(1:120,:),'LineWidth', 3);

hold on
exp_line = plot([1947 1947], [0, 1.2*max(max(pop_gr_disp))]);
shock_line = plot([1970 1970], [0, 1.2*max(max(pop_gr_disp))]);

t1 = text(1933,1.21*max(max(pop_gr_disp)) ,'Expulsion','Interpreter','latex');
t2 = text(1965,1.21*max(max(pop_gr_disp)) ,'$\mathcal{Q}_{rt} = \mathcal{Q}_{r}$','Interpreter','latex');


xlim([1920 inf])
ylim([0, 1.4*max(max(pop_gr_disp))])
grid on
hold off


title('Spatial disperion in annual population growth','Interpreter','latex');
xlabel('Year','Interpreter','latex');

set([exp_line, shock_line] , ...
  'LineStyle'       , '--'           , ...
  'Marker'          , 'none'           , ...
  'Color'           , col.grey    , ...
  'LineWidth'       , 2.5          );

set( gca                       , ...
    'FontName'   , 'Helvetica' , ...
    'FontSize'   , 16          );


print(pop_disp_fig,'-depsc',append(path_appendix,"FigureSM8_dispersion_popgrowth.eps"));
print(pop_disp_fig,'-dpdf',append(path_appendix,"FigureSM8_dispersion_popgrowth.pdf"));





