/* 

This file produces all tables and figures in the paper

"Market Size and Local Growth - Evidence from Germany’s Post-War Population Expulsions"

Date: February 25, 2022

Contact: m.peters@yale.edu
*/

clear

********************************************************************************
*** Define paths
********************************************************************************

* SET MAIN PATH TO YOUR DIRECTORY
local main_path = "_your_path_of_replication_folder"

* Inputs
local path_data = "`main_path'/EmpiricalAnalysis/Data/"
local path_data_fig = "`main_path'/EmpiricalAnalysis/Data_for_Figures/"
local path_modeloutput = "`main_path'/QuantitativeModel/ModelOutput/"


* Outputs
local path_paper = "`main_path'/EmpiricalAnalysis/Results/Paper/"
local path_appendix = "`main_path'/EmpiricalAnalysis/Results/Appendix/"



********************************************************************************
*** Load data
********************************************************************************

use "`path_data'RefugeeData.dta"


********************************************************************************
*** Trunctating pop growth data
********************************************************************************


foreach vv of varlist popgrowth* {
_pctile `vv', percentiles(1, 99)
replace `vv' = . if `vv' < r(r1) | `vv' > r(r2)
}


********************************************************************************
********************************************************************************
********************************************************************************
*** Replication of results: Tables
********************************************************************************
********************************************************************************
********************************************************************************


********************************************************************************
** Table 1: The German Population in Eastern Europe in 1939

* No calculation required. Data comes directly from the original source
********************************************************************************


********************************************************************************
** Table 2: The Settlement of Refugees in West Germany: 1945-1950

* No calculation required. Data comes directly from the original source
********************************************************************************


********************************************************************************
** Table 3: The Population of West Germany: 1939 - 1950

* No calculation required. Data comes directly from the original source
********************************************************************************


********************************************************************************
** Table 4: Characteristics of Refugees and Natives

* No calculation required. Data comes directly from the original source
********************************************************************************



********************************************************************************
** Table 5: Spatial Correlates of Refugee Inflows

local std_error = "cluster(rb)"

eststo clear
foreach xvar of varlist lnExpulsionDistance lnpopdensity_1939 houses_sharedamaged manufac_share_1939 manufac_share_1933 ag_share_1933 Share_Cities02_1939 lny1935  {
eststo: quietly xi: reg refugee_share_1950 `xvar' i.state,  `std_error'
}

esttab using "`path_paper'/Table5_CorrelatesOfInflows.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(lnExpulsionDistance lnpopdensity_1939 houses_sharedamaged manufac_share_1939 manufac_share_1933 ag_share_1933 Share_Cities02_1939 lny1935 ) ///
indicate("State FE = _Istate*" )


esttab using "`path_paper'/Table5_CorrelatesOfInflows.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(lnExpulsionDistance lnpopdensity_1939 houses_sharedamaged manufac_share_1939 manufac_share_1933 ag_share_1933 Share_Cities02_1939 lny1935 ) ///
indicate("State FE = _Istate*" )

********************************************************************************




********************************************************************************
** Table 6: The Effects of Refugee Inflows on the Local Economy

local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "lny1935 manufac_share_1939 lnplants_manufac_1933 ag_share_1933 service_share_1933"
local controls_extended = "Share_Cities02_1939 city lnpopdensity_1933 manufac_share_1933 GDPshare_ag_1935 GDPshare_manufac_1935"
local std_error = "cluster(rb)"

local savepath = "`path_paper'/Table6_effects_refugees_"

foreach depvar of varlist popgrowth3950 popgrowth3961 change_manufac_share3950 change_manufac_share3961 gdp_growth3550 gdp_growth3561 ///
plantgrowth3350 plantgrowth3356 change_ag_share3350 change_ag_share3361 change_service_share3350 change_service_share3361 {

if `depvar' == popgrowth3950 {
*** Panel A: Population growth
eststo clear
local filename = "popgrowth"
local lag_dep_variable = "lnpopulation_1939"
}

if `depvar' == change_manufac_share3950 {
*** Panel B: Manufacturing growth
eststo clear
local filename = "manufacshare"
local lag_dep_variable = "manufac_share_1939"
}

if `depvar' == gdp_growth3550 {
*** Panel C: GDO growth
eststo clear
local filename = "gdpgrowth"
local lag_dep_variable = "lny1935"
}

if `depvar' == plantgrowth3350 {
*** Panel D:  Growth in the number of plants
eststo clear
local filename = "plantgrowth"
local lag_dep_variable = "lnplants_manufac_1933"
}

if `depvar' == change_ag_share3350 {
*** Panel E:  Agricultural share
eststo clear
local filename = "agshare"
local lag_dep_variable = "ag_share_1933"
}

if `depvar' == change_service_share3350 {
*** Panel E:  Service share
eststo clear
local filename = "serviceshare"
local lag_dep_variable = "service_share_1933"
}

eststo: quietly xi: reg `depvar' refugee_share_1950 i.state, `std_error'
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state, `std_error'
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full' i.state, `std_error'
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full' `controls_extended' i.state, `std_error'


if `depvar' == popgrowth3961 | `depvar' == change_manufac_share3961 | `depvar' == gdp_growth3561 | `depvar' == plantgrowth3356 | `depvar' == change_ag_share3361 | `depvar' == change_service_share3361 {

esttab using "`savepath'`filename'.tex", replace se ///
nonumber ///  /* mtitles("1950" "1955" "1961")  ///
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"ln pop dens 1933 = lnpopdensity_1933" "ln plants 1933 = lnplants_manufac_1933" "Agricult. empl. share 1933 = ag_share_1933" ///
"Service empl. share 1933 = service_share_1933" "Additional controls 1933 = Share_Cities02_1939")


esttab using "`savepath'`filename'.txt", replace se ///
nonumber ///  /* mtitles("1950" "1955" "1961")  ///
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"ln pop dens 1933 = lnpopdensity_1933" "ln plants 1933 = lnplants_manufac_1933" "Agricult. empl. share 1933 = ag_share_1933" ///
"Service empl. share 1933 = service_share_1933" "Additional controls 1933 = Share_Cities02_1939")

}
}
********************************************************************************



********************************************************************************
** Table 7: The Effects of Refugee Inflows on the Local Economy: IV Estimates

local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "lny1935 manufac_share_1939 lnplants_manufac_1933 ag_share_1933 service_share_1933"
local controls_extended = "Share_Cities02_1939 city lnpopdensity_1933 manufac_share_1933 GDPshare_ag_1935 GDPshare_manufac_1935"

local savepath = "`path_paper'/Table7_effects_refugees_iv_"
local std_error = "cluster(rb)"


foreach y_var in popgrowth change_manufac_share change_ag_share change_service_share gdp_growth plantgrowth {

eststo clear

if "`y_var'" == "popgrowth" {
local y_short = "`y_var'3950"
local y_long = "`y_var'3961"
local lag_dep_variable = "lnpopulation_1939"
local filename = "`savepath'popgrowth"
}

if "`y_var'" == "change_manufac_share" {
local y_short = "`y_var'3950"
local y_long = "`y_var'3961"
local lag_dep_variable = "manufac_share_1939"
local filename = "`savepath'manufacshare"
}

if "`y_var'" == "change_ag_share" {
local y_short = "`y_var'3350"
local y_long = "`y_var'3361"
local lag_dep_variable = "ag_share_1933"
local filename = "`savepath'agshare"
}

if "`y_var'" == "change_service_share" {
local y_short = "`y_var'3350"
local y_long = "`y_var'3361"
local lag_dep_variable = "service_share_1933"
local filename = "`savepath'serviceshare"
}

if "`y_var'" == "gdp_growth" {
local y_short = "`y_var'3550"
local y_long = "`y_var'3561"
local lag_dep_variable = "lny1935"
local filename = "`savepath'gdpgrowth"
}
 
if "`y_var'" == "plantgrowth" {
local y_short = "`y_var'3350"
local y_long = "`y_var'3356"
local lag_dep_variable = "lnplants_manufac_1933"
local filename = "`savepath'plantgrowth"
}


eststo: quietly xi: ivregress 2sls `y_short' (refugee_share_1950 = i.state*lnExpulsionDistance) i.state, `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_short' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_short' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_short' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full' `controls_extended', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4]

eststo: quietly xi: ivregress 2sls `y_long' (refugee_share_1950 = i.state*lnExpulsionDistance) i.state, `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_long' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_long' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 

eststo: quietly xi: ivregress 2sls `y_long' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `lag_dep_variable' `controls_full' `controls_extended', `std_error'
estat firststage
mat f = r(singleresults)
estadd scalar f_stat_sr = f[1,4] 


esttab using "`filename'.tex", replace ///
se label star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
stats(N r2 f_stat_sr, fmt(0 3) labels(`"\(N\)"'  `"\(R^{2}\)"' `"\(F\)"')) ///
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"ln plants 1933 = lnplants_manufac_1933" "Agricult. empl. share 1933 = ag_share_1933" ///
"Service. empl. share 1933 = service_share_1933" "Additional controls 1933 = Share_Cities02_1939")


esttab using "`filename'.txt", replace ///
se label star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
stats(N r2 f_stat_sr, fmt(0 3) labels(`"\(N\)"'  `"\(R^{2}\)"' `"\(F\)"')) ///
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"ln plants 1933 = lnplants_manufac_1933" "Agricult. empl. share 1933 = ag_share_1933" ///
"Service. empl. share 1933 = service_share_1933" "Additional controls 1933 = Share_Cities02_1939")

}


********************************************************************************



********************************************************************************
** Table 8: The Effects of Refugee Inflows on the Local Economy: Variation Within Counties


preserve
clear
use "`path_data'RefugeeData_VillagesBavaria.dta"

local controls_villages = "lnpopdensity_1933 manufac_share_1939 lnpopdensity_1939 i.county"
local std_error = "cluster(county)"


eststo clear
*** Implications of refugee allocation
eststo: quietly xi: reg popgrowth3950 refugee_share_1950  `controls_villages', `std_error'
eststo: quietly xi: reg change_manufac_share3950 refugee_share_1950 `controls_villages', `std_error'
eststo: quietly xi: reg change_ag_share3950 refugee_share_1950 `controls_villages', `std_error'
eststo: quietly xi: reg refugee_share_1961 refugee_share_1950 i.county, `std_error'
eststo: quietly xi: reg popgrowth3961 refugee_share_1950 `controls_villages', `std_error'
eststo: quietly xi: reg change_manufac_share3961 refugee_share_1950 `controls_villages', `std_error'
eststo: quietly xi: reg change_ag_share3961 refugee_share_1950 `controls_villages', `std_error'


esttab using "`path_paper'Table8_village_analysis.tex", replace se ///
nonumber ///  /* mtitles("1950" "1955" "1961")  ///
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950)  ///
indicate("County FE = _Icounty*" ///
"Pre-war pop density 33 = lnpopdensity_1933" ///
"Pre-war pop density 39 = lnpopdensity_1939" ///
"Manufac. share (1939) = manufac_share_1939")



esttab using "`path_paper'Table8_village_analysis.txt", replace se ///
nonumber ///  /* mtitles("1950" "1955" "1961")  ///
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950)  ///
indicate("County FE = _Icounty*" ///
"Pre-war pop density 33 = lnpopdensity_1933" ///
"Pre-war pop density 39 = lnpopdensity_1939" ///
"Manufac. share (1939) = manufac_share_1939")

restore

********************************************************************************



********************************************************************************
** Table 9: The Manufacturing Bias of Refugees' Labor Supply


gen manufac_premium_ref = manufac_share_refugees_1950/manufac_share_natives_1950 
gen ag_premium_ref = ag_share_refugees_1950/ag_share_natives_1950 
gen index = 1


tabout index using "`path_paper'Table9_refugee_bias.txt", replace f(2c) ///
sum c(mean manufac_premium_ref p10 manufac_premium_ref p25 manufac_premium_ref p50 manufac_premium_ref p75 manufac_premium_ref p90 manufac_premium_ref ///  
	  mean ag_premium_ref p10 ag_premium_ref p25 ag_premium_ref p50 ag_premium_ref p75 ag_premium_ref p90 ag_premium_ref) 


drop index manufac_premium_ref ag_premium_ref
********************************************************************************



********************************************************************************
** Table 10: Additional Moments for Quantitative Analysis

local controls_basic "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography "lndistance Border"
local std_error = "cluster(rb)"

local filename = "`path_paper'Table10_Addtl_moments"

eststo clear

** Population growth 1950-1955
eststo: quietly xi: reg popgrowth5055 refugee_share_1950 `controls_basic' `controls_geography', `std_error'

** Long-run Effects: 1950-1980
preserve 
clear
use "`path_data'RefugeeData_1975.dta"

*(i) Population growth
eststo: quietly xi: reg popgrowth3980 refugee_share_1950 lnpopulation_1939 `controls_basic' `controls_geography', `std_error'
*(ii) Income growth
eststo: quietly xi: reg gdp_growth3580 refugee_share_1950 lny1935 `controls_basic' `controls_geography', `std_error'
restore

esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" ///
"log GDPpc 1935 = lny1935" "Population 1939 = lnpopulation_1939"  "Geography = Border"  )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" ///
"log GDPpc 1935 = lny1935" "Population 1939 = lnpopulation_1939"  "Geography = Border"  )

********************************************************************************


********************************************************************************
** Table 11: Structural Parameters and Model Fit
* Extracted from Quantitative Analysis
********************************************************************************


********************************************************************************
** Table 12: Spatial Sorting and Rural Industrialization


preserve 

** (1) Load data from model
clear
import delimited "`path_modeloutput'Table12_model_data.csv"
ren kreis_id KREIS_ID
sort KREIS_ID 
save "`path_modeloutput'Table12_model_data.dta", replace

** (2) Merge to real data 
clear 
use "`path_data'RefugeeData.dta"
sort KREIS_ID
merge 1:1 KREIS_ID using "`path_modeloutput'Table12_model_data.dta"
rm "`path_modeloutput'Table12_model_data.dta"

** (3) Define variables

local industrialization_measure = "manufac_share_1939"
local industrialization_measure_model = "manuf_share_model_1939"  

gen Urban_int = refugee_share_1950*`industrialization_measure'
gen Urban_int_model = refshare_model_1950*`industrialization_measure_model'

gen Refugee_bias = manufac_share_refugees_1950 - manufac_share_natives_1950
replace Refugee_bias = . if state != "Bavaria"
gen Refugee_bias_model = manuf_share_ref_model_1950 - manuf_share_nat_model_1950

gen change_manufac_share3950_model = manuf_share_model_1950 - `industrialization_measure_model'
label var Urban_int "s_{rM1939} \times Share of refugees in 1950"

** (4) Define controls, sample, std errors and filename
local controls_basic "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography "lndistance Border"
local std_error = "cluster(rb)"
local filename = "`path_paper'Table12_spatial_sorting"

gen SampleSel = missing(refshare_model_1950) == 0

eststo clear
eststo: quietly xi: reg ind_share_model_1933 `industrialization_measure_model' if SampleSel == 1, `std_error'
eststo: quietly xi: reg Refugee_bias_model `industrialization_measure_model' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'
eststo: quietly xi: reg change_manufac_share3950_model refshare_model_1950  `industrialization_measure_model' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'
eststo: quietly xi: reg change_manufac_share3950_model refshare_model_1950 Urban_int_model `industrialization_measure_model' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'

eststo: quietly xi: reg Refugee_bias `industrialization_measure' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'
eststo: quietly xi: reg change_manufac_share3950 refugee_share_1950  `industrialization_measure' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'
eststo: quietly xi: reg change_manufac_share3950 refugee_share_1950 Urban_int `industrialization_measure' `controls_basic' `controls_geography' if SampleSel == 1, `std_error'

drop SampleSel


esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950  Urban_int `industrialization_measure' refshare_model_1950 Urban_int_model `industrialization_measure_model' ) ///
order(`industrialization_measure_model' refshare_model_1950 Urban_int_model `industrialization_measure' refugee_share_1950  Urban_int    ) ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "State FE = _Istate*" )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950  Urban_int `industrialization_measure' refshare_model_1950 Urban_int_model `industrialization_measure_model' ) ///
order(`industrialization_measure_model' refshare_model_1950 Urban_int_model `industrialization_measure' refugee_share_1950  Urban_int    ) ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "State FE = _Istate*" )

restore
********************************************************************************




********************************************************************************
*** Table SM_1: Composition of refugee inflows 

local std_error = "cluster(rb)"
local controls_basic "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"

local filename = "`path_appendix'TableSM1_local_composition"


eststo clear
foreach depvar of varlist refugeeSudeten_share_1950 refugeeReich_share_1950 SBZ_share {
eststo: quietly xi: reg `depvar' lny1935 i.state `controls_basic' `controls_geography', `std_error'
eststo: quietly xi: reg `depvar' manufac_share_1939 i.state `controls_basic' `controls_geography', `std_error'
}

esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(lny1935 manufac_share_1939) ///
order(lny1935 manufac_share_1939)  ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" "State FE = _Istate*" )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(lny1935 manufac_share_1939) ///
order(lny1935 manufac_share_1939)  ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" "State FE = _Istate*" )

********************************************************************************




********************************************************************************
** Tables SM_2 & SM_3: ROBUSTNESS OF OLS ESTIMATES


local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local std_error = "cluster(rb)"


foreach depvar of varlist popgrowth3950 popgrowth3961 change_manufac_share3950 change_manufac_share3961 gdp_growth3550 gdp_growth3561 ///
plantgrowth3350 plantgrowth3356 change_ag_share3350 change_ag_share3361 change_service_share3350 change_service_share3361 {


*** Panel A: Population growth
if `depvar' == popgrowth3950 {
local filename = "TableSM2_robustness_ols_popgrowth_1950"
local lag_dep_variable = "lnpopulation_1939"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == popgrowth3961 {
local filename = "TableSM3_robustness_ols_popgrowth_1961"
local lag_dep_variable = "lnpopulation_1939"
local controls_labsupply "male_share_1961 empl_share_1961"
}

*** Panel B: Manufacturing growth
if `depvar' == change_manufac_share3950 {
local filename = "TableSM2_robustness_ols_manufacshare_1950"
local lag_dep_variable = "manufac_share_1939"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_manufac_share3961 {
local filename = "TableSM3_robustness_ols_manufacshare_1961"
local lag_dep_variable = "manufac_share_1939"
local controls_labsupply "male_share_1961 empl_share_1961"
}

*** Panel C: GDP growth
if `depvar' == gdp_growth3550 {
local filename = "TableSM2_robustness_ols_gdpgrowth_1950"
local lag_dep_variable = "lny1935"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == gdp_growth3561 {
local filename = "TableSM3_robustness_ols_gdpgrowth_1961"
local lag_dep_variable = "lny1935"
local controls_labsupply "male_share_1961 empl_share_1961"
}


*** Panel D:  Growth in the number of plants
if `depvar' == plantgrowth3350 {
local filename = "TableSM2_robustness_ols_plantgrowth_1950"
local lag_dep_variable = "lnplants_manufac_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == plantgrowth3356 {
local filename = "TableSM3_robustness_ols_plantgrowth_1956"
local lag_dep_variable = "lnplants_manufac_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

*** Panel E:  Agricultural share
if `depvar' == change_ag_share3350 {
local filename = "TableSM2_robustness_ols_agshare_1950"
local lag_dep_variable = "ag_share_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_ag_share3361 {
local filename = "TableSM3_robustness_ols_agshare_1961"
local lag_dep_variable = "ag_share_1933"
local controls_labsupply "male_share_1961 empl_share_1961"
}


*** Panel F:  Service share
if `depvar' == change_service_share3350 {
local filename = "TableSM2_robustness_ols_serviceshare_1950"
local lag_dep_variable = "service_share_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_service_share3361 {
local filename = "TableSM3_robustness_ols_serviceshare_1961"
local lag_dep_variable = "service_share_1933"
local controls_labsupply "male_share_1961 empl_share_1961"
}



eststo clear
** Baseline
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state, `std_error'
** Weighted with 1939 population
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state [aw = population_1939], `std_error'
** Controlling for labor Supply
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_labsupply' `controls_allocation' `controls_geography' `lag_dep_variable' i.state, `std_error'
** Controlling for construction activity
eststo: quietly xi: reg `depvar' refugee_share_1950 houses_share1945 `controls_allocation' `controls_geography' `lag_dep_variable' i.state, `std_error'
** City * State FE
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state*i.city, `std_error'
** Excluding Bavaria
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state if state != "Bavaria", `std_error'
** Refugee share in 1946
eststo: quietly xi: reg `depvar' refugee_share_1946 `controls_allocation' `controls_geography' `lag_dep_variable' i.state, `std_error'
** Basic specification on 1946 sample
eststo: quietly xi: reg `depvar' refugee_share_1950 `controls_allocation' `controls_geography' `lag_dep_variable' i.state if missing(refugee_share_1946) == 0, `std_error'


esttab using "`path_appendix'`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1946) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Labor Supply = `controls_labsupply'" "Reconstruction = houses_share1945" "City FE = _Icity*")

esttab using "`path_appendix'`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1946) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Labor Supply = `controls_labsupply'" "Reconstruction = houses_share1945" "City FE = _Icity*")
}

********************************************************************************




********************************************************************************
*** Table SM_4: FIRST STAGE
local filename = "`path_appendix'TableSM4_first_stage"


* Generate interactions of expulsion distance within states
gen intlnExp_BW = lnExpulsionDistance * (state == "Baden_Wuerttemberg")
gen intlnExp_Bav = lnExpulsionDistance * (state == "Bavaria")
gen intlnExp_Hesse = lnExpulsionDistance * (state == "Hesse")
gen intlnExp_NRW = lnExpulsionDistance * (state == "NRW")
gen intlnExp_NS = lnExpulsionDistance * (state == "Niedersachsen")
gen intlnExp_Rpf = lnExpulsionDistance * (state == "RhPf")
gen intlnExp_SH = lnExpulsionDistance * (state == "SH")

local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_firststage = "lny1935 manufac_share_1939 ag_share_1933"

eststo clear

eststo: quietly xi: reg refugee_share_1950 lnExpulsionDistance `controls_allocation' `controls_geography', robust
eststo: quietly xi: reg refugee_share_1950 lnExpulsionDistance intlnExp_Bav `controls_allocation' `controls_geography', robust
eststo: quietly xi: reg refugee_share_1950 intlnExp_*  `controls_allocation' `controls_geography', robust
eststo: quietly xi: reg refugee_share_1950 intlnExp_*  `controls_firststage' `controls_allocation' `controls_geography', robust
eststo: quietly xi: reg refugee_share_1950 lnExpulsionDistance `controls_allocation' `controls_geography', cluster(rb)
eststo: quietly xi: reg refugee_share_1950 lnExpulsionDistance intlnExp_Bav `controls_allocation' `controls_geography', cluster(rb)
eststo: quietly xi: reg refugee_share_1950 intlnExp_*  `controls_allocation' `controls_geography', cluster(rb)
eststo: quietly xi: reg refugee_share_1950 intlnExp_*  `controls_firststage' `controls_allocation' `controls_geography', cluster(rb)

esttab using "`filename'.tex", replace ///
compress se  label star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(lnExpulsionDistance intlnExp_*) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"Agricult. empl. share 1933 = ag_share_1933" )

esttab using "`filename'.txt", replace ///
compress se  label star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(lnExpulsionDistance intlnExp_*) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Manufac. empl. share 1939 = manufac_share_1939" "lny 1935 = lny1935" ///
"Agricult. empl. share 1933 = ag_share_1933" )


drop intlnExp_*
********************************************************************************




********************************************************************************
** Tables SM_5 & SM_6: Robustness for IV estimates

local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "lnpopdensity_1933 lny1935 manufac_share_1939 lnplants_manufac_1933 ag_share_1933 service_share_1933"
local controls_geography_interact = "i.state*lndistance Border"
local std_error = "cluster(rb)"


local savepath_short = "`path_appendix'TableSM5_iv_robustness_"
local savepath_long = "`path_appendix'TableSM6_iv_robustness_"


foreach depvar of varlist popgrowth3950 popgrowth3961 change_manufac_share3950 change_manufac_share3961 gdp_growth3550 gdp_growth3561 ///
plantgrowth3350 plantgrowth3356 change_ag_share3350 change_ag_share3361 change_service_share3350 change_service_share3361 {


*** Panel A: Population growth
if `depvar' == popgrowth3950 {
local filename = "TableSM5_robustness_iv_popgrowth_1950"
local lag_dep_variable = "lnpopulation_1939"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == popgrowth3961 {
local filename = "TableSM6_robustness_iv_popgrowth_1961"
local lag_dep_variable = "lnpopulation_1939"
local controls_labsupply "male_share_1961 empl_share_1961"
}

*** Panel B: Manufacturing growth
if `depvar' == change_manufac_share3950 {
local filename = "TableSM5_robustness_iv_manufacshare_1950"
local lag_dep_variable = "manufac_share_1939"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_manufac_share3961 {
local filename = "TableSM6_robustness_iv_manufacshare_1961"
local lag_dep_variable = "manufac_share_1939"
local controls_labsupply "male_share_1961 empl_share_1961"
}

*** Panel C: GDP growth
if `depvar' == gdp_growth3550 {
local filename = "TableSM5_robustness_iv_gdpgrowth_1950"
local lag_dep_variable = "lny1935"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == gdp_growth3561 {
local filename = "TableSM6_robustness_iv_gdpgrowth_1961"
local lag_dep_variable = "lny1935"
local controls_labsupply "male_share_1961 empl_share_1961"
}


*** Panel D:  Growth in the number of plants
if `depvar' == plantgrowth3350 {
local filename = "TableSM5_robustness_iv_plantgrowth_1950"
local lag_dep_variable = "lnplants_manufac_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == plantgrowth3356 {
local filename = "TableSM6_robustness_iv_plantgrowth_1956"
local lag_dep_variable = "lnplants_manufac_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

*** Panel E:  Agricultural share
if `depvar' == change_ag_share3350 {
local filename = "TableSM5_robustness_iv_agshare_1950"
local lag_dep_variable = "ag_share_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_ag_share3361 {
local filename = "TableSM6_robustness_iv_agshare_1961"
local lag_dep_variable = "ag_share_1933"
local controls_labsupply "male_share_1961 empl_share_1961"
}


*** Panel F:  Service share
if `depvar' == change_service_share3350 {
local filename = "TableSM5_robustness_iv_serviceshare_1950"
local lag_dep_variable = "service_share_1933"
local controls_labsupply "male_share_1950 empl_share_1950"
}

if `depvar' == change_service_share3361 {
local filename = "TableSM6_robustness_iv_serviceshare_1961"
local lag_dep_variable = "service_share_1933"
local controls_labsupply "male_share_1961 empl_share_1961"
}



eststo clear
** Baseline
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `controls_full' `lag_dep_variable', `std_error'
** Controlling for labor Supply
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_labsupply' `controls_allocation' `controls_geography' `controls_full' `lag_dep_variable', `std_error'
** Controlling for construction activity
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) houses_share1945 `controls_allocation' `controls_geography' `controls_full'  `lag_dep_variable', `std_error'
** City * State FE
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) i.state*i.city `controls_allocation' `controls_geography' `controls_full'  `lag_dep_variable', `std_error'
** Excluding Bavaria
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `controls_full'  `lag_dep_variable' if state != "Bavaria", `std_error'
** Refugee share in 1946
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1946 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `controls_full'  `lag_dep_variable', `std_error'
** Basic specification on 1946 sample
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography' `controls_full'  `lag_dep_variable' if missing(refugee_share_1946) == 0, `std_error'
** Control for covariates interacted with state fixed effect
eststo: quietly xi: ivregress 2sls `depvar' (refugee_share_1950 = i.state*lnExpulsionDistance) `controls_allocation' `controls_geography_interact' `controls_full'  `lag_dep_variable', `std_error'


esttab using "`path_appendix'`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1946) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Pre-war controls = lnpopdensity_1933" "Labor Supply = `controls_labsupply'" "Reconstruction = houses_share1945" "City FE = _Icity*")


esttab using "`path_appendix'`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1946) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "Pre-war controls = lnpopdensity_1933" "Labor Supply = `controls_labsupply'" "Reconstruction = houses_share1945" "City FE = _Icity*")
}

********************************************************************************


********************************************************************************
** Table SM_7: PRE-TRENDS

local filename = "`path_appendix'TableSM7_pretrends"
local std_error = "cluster(rb)"
local controls_basic "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography "lndistance Border"

* Pre-trend variables
gen popgrowth_pre = lnpopulation_1939 - lnpopulation_1933 
gen change_manufac_share_pre = manufac_share_1939 - manufac_share_1933
gen plantgrowth_pre = lnplants_total_1939 - lnplants_total_1933

eststo clear
foreach depvar of varlist manufac_share_1933 manufac_share_1939 ag_share_1933 popgrowth_pre change_manufac_share_pre plantgrowth_pre  {
eststo: quietly xi: reg `depvar' refugee_share_1950 i.state `controls_basic' `controls_geography', `std_error'
}

esttab using "`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "State FE = _Istate*" )

esttab using "`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "State FE = _Istate*" )

drop popgrowth_pre change_manufac_share_pre plantgrowth_pre 
********************************************************************************




********************************************************************************
** Table SM_8: Spatial Mobility within counties: 1950 - 1961

preserve
clear
use "`path_data'RefugeeData_VillagesBavaria.dta"

local filename = "`path_appendix'TableSM8_mobility_within_counties"
local std_error = "cluster(county)"

eststo clear
* Subsequent population growth
eststo: quietly xi: reg popgrowth5061 refugee_share_1950 i.county, `std_error'
eststo: quietly xi: reg popgrowth5061 refugee_share_1950 lnpopulation_1950 lnpopdensity_1939 i.county, `std_error'
eststo: quietly xi: reg popgrowth5061 refugee_share_1950_* lnpopulation_1950 lnpopdensity_1939 i.county, `std_error'

* Correlation of refugee share
eststo: quietly xi: reg refugee_share_1961 refugee_share_1950 lnpopdensity_1939 lnpopulation_1950 i.county, `std_error'
eststo: quietly xi: reg refugee_share_1961 refugee_share_1950_* lnpopdensity_1939 lnpopulation_1950 i.county, `std_error'

esttab using "`filename'.tex", replace se ///
nonumber ///  
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1950_*)  ///
order(refugee_share_1950 refugee_share_1950_*) ///
indicate("County FE = _Icounty*" /// 
"ln Population 1950 = lnpopulation_1950" ///
"Pop. dens. 1939 = lnpopdensity_1939")

esttab using "`filename'.txt", replace se ///
nonumber ///  
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 refugee_share_1950_*)  ///
order(refugee_share_1950 refugee_share_1950_*) ///
indicate("County FE = _Icounty*" /// 
"ln Population 1950 = lnpopulation_1950" ///
"Pop. dens. 1939 = lnpopdensity_1939")

restore
********************************************************************************




********************************************************************************
** Table SM_9: Moments for Quantitative Analysis 

local filename = "`path_appendix'TableSM9_moments_for_quant_analysis"


local controls_basic "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography "lndistance Border"
local std_error = "cluster(rb)"


eststo clear
******************** (1) Short- and long run effect on GDPpc
** 1950
eststo: quietly xi: reg gdp_growth3550 refugee_share_1950 lny1935 `controls_basic' `controls_geography', `std_error'

** 1961 (with distance coefficient)
gen lndistance61 = lndistance
eststo: quietly xi: reg gdp_growth3561 refugee_share_1950 lndistance61 lny1935 `controls_basic' Border, `std_error'
drop lndistance61

** 1980 
preserve 
clear
use "`path_data'RefugeeData_1975.dta"
eststo: quietly xi: reg gdp_growth3580 refugee_share_1950 lny1935 `controls_basic' `controls_geography', `std_error'
restore

******************** (2) Short- and long run effect on Manufacturing employment
eststo: quietly xi: reg change_manufac_share3950 refugee_share_1950 manufac_share_1939 `controls_basic' `controls_geography', `std_error'
eststo: quietly xi: reg change_manufac_share3961 refugee_share_1950 manufac_share_1939 `controls_basic' `controls_geography', `std_error'

******************** (3) Short- and long run effect on population growth
eststo: quietly xi: reg popgrowth3950 refugee_share_1950 lnpopulation_1939 `controls_basic' `controls_geography', `std_error'
eststo: quietly xi: reg popgrowth3961 refugee_share_1950 lnpopulation_1939 `controls_basic' `controls_geography', `std_error'

** 1980 
preserve 
clear
use "`path_data'RefugeeData_1975.dta"
eststo: quietly xi: reg popgrowth3980 refugee_share_1950 lnpopulation_1939 `controls_basic' `controls_geography', `std_error'
restore

******************** (4) Short- and long run persistence of refugee shares
eststo: quietly xi: reg refugee_share_1955 refugee_share_1950 i.state, `std_error'
eststo: quietly xi: reg refugee_share_1961 refugee_share_1950 i.state, `std_error'

esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950 lndistance61) ///
order(refugee_share_1950 lndistance61) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" ///
"log GDPpc 1935 = lny1935"  "Manufac. share 1939 = manufac_share_1939" "Population 1939 = lnpopulation_1939" ///
"Geography = Border" )


esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950 lndistance61) ///
order(refugee_share_1950 lndistance61) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" ///
"log GDPpc 1935 = lny1935"  "Manufac. share 1939 = manufac_share_1939" "Population 1939 = lnpopulation_1939" ///
"Geography = Border" )

********************************************************************************





********************************************************************************
** Table SM_9a: Additonal Moments for Quantitative Analysis 

local filename = "`path_appendix'TableSM9a_addtl_moments"

eststo clear
* (1) Relative earnings of refugees
preserve
clear
use "`path_data'EVS1962.dta"

gen sample = 1
replace sample = 0 if age < 16 | age > 65
replace sample = 0 if occupation == 7 | occupation == 8 /* Retired */
replace sample = 0 if occupation == 9 /* Not employed */

eststo: quietly xi: reg lnincome refugeeeast age agesq male i.state if sample == 1, robust
restore
 
*(2) Stochastic process of GDP pc 
** Construct panel structure to run panel regression with county fixed effect

preserve
gen county_id = [_n]
keep lnGDPpw* county_id countyname countytype state

reshape long lnGDPpw, i(county_id countyname countytype state) j(year)

sort county_id year
by county_id: gen lnGDPpw_lag = lnGDPpw[_n-1] 

* Run regression and save coefficient on lag GDP
eststo: quietly xi: areg  lnGDPpw  lnGDPpw_lag, absorb(county_id) robust

* Calculate dispersion of residuals
predict u_raw, residuals
egen qL = pctile(u_raw), p(2)
egen qH = pctile(u_raw), p(98)
gen u_censored = u_raw
replace u_censored = . if u_raw <= qL
replace u_censored = . if u_raw >= qH


gen index = 1
tabout index using "`path_appendix'TableSM9b_addtl_moments_dispersion_residuals.txt", replace f(3c) ///
sum c(sd u_censored iqr u_censored sd u_raw iqr u_raw) 
drop index

restore


esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugeeeast lnGDPpw_lag ) ///
order(refugeeeast lnGDPpw_lag ) ///
indicate("State FE = _Istate*" "Demographics = age" )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugeeeast lnGDPpw_lag ) ///
order(refugeeeast lnGDPpw_lag ) ///
indicate("State FE = _Istate*" "Demographics = age" )

********************************************************************************



********************************************************************************
** Table SM_10: The Long-Run Effect of the Refugee Settlement: GDP pc growth

preserve 

clear
use "`path_data'RefugeeData_1975.dta"

local filename = "`path_appendix'TableSM10_stationarity_income"
local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "manufac_share_1939"
local std_error = "cluster(rb)"


eststo clear
foreach yy of varlist gdp_growth35* {

if "`yy'" != "gdp_growth3570_tax" {
eststo: quietly xi: reg `yy' refugee_share_1950 lny1935 `controls_allocation' `controls_geography' `controls_full', `std_error'
}
}

esttab using "`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" "Manufac. share 1939 = manufac_share_1939")

esttab using "`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" "Manufac. share 1939 = manufac_share_1939")

restore

********************************************************************************


********************************************************************************
** Table SM_11: The Long-Run Effect of the Refugee Settlement: Population growth

preserve 

clear
use "`path_data'RefugeeData_1975.dta"

local filename = "`path_appendix'TableSM11_stationarity_pop"
local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "manufac_share_1939"
local std_error = "cluster(rb)"

foreach vv of varlist popgrowth* {
_pctile `vv', percentiles(3, 97)
replace `vv' = . if `vv' < r(r1) | `vv' > r(r2)
}


eststo clear
foreach yy of varlist popgrowth39* {

if "`yy'" != "popgrowth3946" {
eststo: quietly xi: reg `yy' refugee_share_1950 lnpopulation_1939 `controls_allocation' `controls_geography' `controls_full', `std_error'
}
}

esttab using "`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lnpop 1939 = lnpopulation_1939" "Manufac. share 1939 = manufac_share_1939")

esttab using "`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lnpop 1939 = lnpopulation_1939" "Manufac. share 1939 = manufac_share_1939")

restore

********************************************************************************




********************************************************************************
** Table SM_12: GDP vs Value Added

preserve 

clear
use "`path_data'RefugeeData_1975.dta"

local filename = "`path_appendix'TableSM12_gdp_va"
local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local std_error = "cluster(rb)"

eststo clear
eststo: quietly xi: reg gdp_growth3566 refugee_share_1950 `controls_allocation' `controls_geography' lny1935 i.state, `std_error'
eststo: quietly xi: reg gdp_growth3570 refugee_share_1950 `controls_allocation' `controls_geography' lny1935 i.state, `std_error'
eststo: quietly xi: reg gdp_growth3572 refugee_share_1950 `controls_allocation' `controls_geography' lny1935 i.state, `std_error'
eststo: quietly xi: reg gdp_growth3574 refugee_share_1950 `controls_allocation' `controls_geography' lny1935 i.state, `std_error'
eststo: quietly xi: reg gdp_growth3570_tax refugee_share_1950 `controls_allocation' `controls_geography' lny1935 i.state, `std_error'

esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" )

restore
********************************************************************************



********************************************************************************
********************************************************************************
********************************************************************************
*** Replication of results: Figures
********************************************************************************
********************************************************************************
********************************************************************************



********************************************************************************
** Figure 2: The Distribution of Refugees

local filename = "`path_paper'Figure2_histogram_refugees"

egen refugees_agg = sum(refugees_1950)
egen pop_agg = sum(population_1950)
gen ref_share_agg = refugees_agg/pop_agg

levelsof ref_share_agg, loc(aggref)

histogram refugee_share_1950, bin(12) ///
fcolor(gs12) lcolor(gs2) ///
graphregion(color(white))  ytitle("") addplot(pci 0 `aggref' 6 `aggref', lcolor(gs3) lwidth(thick)  lpattern(dash)) ///
text(5.5 `aggref' " Aggregate share", place(e)) ///
xtitle("County-level share of refugees in 1950") legend(off)
gr export "`filename'.pdf", replace

gr drop _all
drop refugees_agg pop_agg ref_share_agg
********************************************************************************



********************************************************************************
** Figure 2: Spatial correlation of refugees 1950-1955 and 1950-1961

** Calculate binscatter and export to cvs file. Figure is constructed in "plot_figures_MarketSizeSpatialGrowth.m"

binscatter refugee_share_1955 refugee_share_1950, n(100) savedata(`path_data_fig'Figure2_refshare_5055_binscatter) replace 
rm "`path_data_fig'Figure2_refshare_5055_binscatter.do"
binscatter refugee_share_1961 refugee_share_1950, n(100) savedata(`path_data_fig'Figure2_refshare_5061_binscatter) replace 
rm "`path_data_fig'Figure2_refshare_5061_binscatter.do"
gr drop _all
********************************************************************************



********************************************************************************
** Figure 4: Model Fit (Estimate regression coefficients and std error for results depicted in Table 4)

** Compute empirical elasticities and stadard errors. Figure is constructed in "plot_figures_MarketSizeSpatialGrowth.m"

local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local std_error = "cluster(rb)"


** Baseline sample
local filename = "`path_data_fig'Figure4_gdp_baseline_sample"

eststo clear
foreach depvar of varlist gdp_growth3550 gdp_growth3557 gdp_growth3561 gdp_growth3564 gdp_growth3566 {
eststo: quietly xi: reg `depvar' refugee_share_1950 lny1935 `controls_allocation' `controls_geography' i.state, `std_error'
}

esttab using "`filename'.tex", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" )

esttab using "`filename'.txt", replace ///
se label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
nonumber  /// 
keep(refugee_share_1950) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" )


** Use data in 1975, which also has the data in the 80s and 90s 
preserve 
clear
use "`path_data'RefugeeData_1975.dta"

**** Define controls
local controls_allocation = "lnpopdensity_1939 houses_sharedamaged i.state"
local controls_geography = "lndistance Border"
local controls_full = "manufac_share_1939"
local std_error = "cluster(rb)"



**************** GDP growth
local filename = "`path_data_fig'Figure4_gdp_longrun_sample"

eststo clear
foreach yy of varlist gdp_growth35* {

if "`yy'" != "gdp_growth3570_tax" {
eststo: quietly xi: reg `yy' refugee_share_1950 lny1935 `controls_allocation' `controls_geography' `controls_full', `std_error'
}
}

esttab using "`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" "Manufac. share 1939 = manufac_share_1939")

esttab using "`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lny 1935 = lny1935" "Manufac. share 1939 = manufac_share_1939")


**************** PopulationGrowth growth
local filename = "`path_data_fig'Figure4_pop_longrun_sample"

eststo clear
foreach vv of varlist popgrowth* {
_pctile `vv', percentiles(3, 97)
replace `vv' = . if `vv' < r(r1) | `vv' > r(r2)
}

foreach yy of varlist popgrowth39* {

if "`yy'" != "popgrowth3946" {
eststo: quietly xi: reg `yy' refugee_share_1950 lnpopulation_1939 `controls_allocation' `controls_geography' `controls_full', `std_error'
}
}

esttab using "`filename'.tex", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lnpop 1939 = lnpopulation_1939") 

esttab using "`filename'.txt", replace se ///
nonumber /// 
compress label r2 star(* 0.10 ** 0.05 *** 0.01) b(%8.3f) ///
keep(refugee_share_1950 ) ///
indicate("State FE = _Istate*" "ln pop dens 1939 = lnpopdensity_1939" "Wartime destr. = houses_sharedamaged" /// 
"Geography = Border" "lnpop 1939 = lnpopulation_1939") 


restore
********************************************************************************



********************************************************************************
** Figure 5: Spatial implications

** Calculate binscatter and export to cvs file. Figure is constructed in "plot_figures_MarketSizeSpatialGrowth.m"

preserve
clear
import delimited "`path_modeloutput'Figure5_spatial_implications.csv"


** Calculate binscatter for one sample path and export to cvs file

local simnum = "1"

gen dy50 = (y_withref_1950_sim_`simnum' - y_noref_1950_sim_`simnum')/y_noref_1950_sim_`simnum'
gen dy61 = (y_withref_1961_sim_`simnum' - y_noref_1961_sim_`simnum')/y_noref_1961_sim_`simnum'

gen dman50 = manuf_share_withref_1950_sim_`simnum' - manuf_share_noref_1950_sim_`simnum'
gen dman61 = manuf_share_withref_1961_sim_`simnum' - manuf_share_noref_1961_sim_`simnum'

binscatter  dy50 refugee_share_1950_data, n(100) savedata(`path_data_fig'Figure5_spatial_implications_dy50_binscatter) replace
rm "`path_data_fig'Figure5_spatial_implications_dy50_binscatter.do"
binscatter  dy61 refugee_share_1950_data, n(100) savedata(`path_data_fig'Figure5_spatial_implications_dy61_binscatter) replace
rm "`path_data_fig'Figure5_spatial_implications_dy61_binscatter.do"

drop dy50 dy61 
gr drop _all
restore
********************************************************************************



********************************************************************************
** Figure 6: Demand Supply decomposition

** Calculate binscatter and export to cvs file. Figure is constructed in "plot_figures_MarketSizeSpatialGrowth.m"

preserve
clear
import delimited "`path_modeloutput'Figure6_supply_demand.csv"


foreach vv of varlist dy_* dman_* {
rename `vv' `vv'_base
}

foreach vv of varlist ///
dy_1950_r_l_full_base dy_1961_r_l_full_base dy_1950_r_l_demand_base ///
dy_1961_r_l_demand_base dy_1961_r_l_supply_base dy_1950_r_l_supply_base {
binscatter  `vv' refugee_share_1950_data, n(100) savedata(`path_data_fig'Figure6_demand_supply_binscatter_`vv') replace
rm "`path_data_fig'Figure6_demand_supply_binscatter_`vv'.do"
}

foreach vv of varlist ///
dman_61_r_l_full_base dman_61_r_l_supply_base dman_61_r_l_demand_base ///
dman_50_r_l_full_base dman_50_r_l_supply_base dman_50_r_l_demand_base {
binscatter  `vv' refugee_share_1950_data, n(100) savedata(`path_data_fig'FigureSM10_demand_supply_binscatter_`vv') replace
rm "`path_data_fig'FigureSM10_demand_supply_binscatter_`vv'.do"
}

gr drop _all
restore
********************************************************************************



********************************************************************************
** Figure 7: Rural Industrialization

** Calculate binscatter and export to cvs file. Figure is constructed in "plot_figures_MarketSizeSpatialGrowth.m"

preserve
clear
use "`path_data'RefugeeData.dta"
keep KREIS_ID state lnpopdensity_1939 lnpopdensity_1933
ren KREIS_ID kreis_id
sort kreis_id state
save "`path_modeloutput'tmp.dta", replace


clear
import delimited "`path_modeloutput'Figure7_rural_industrialization_space.csv"
sort kreis_id state
merge 1:1 kreis_id state using "`path_modeloutput'tmp.dta"
keep if _merge == 3
drop _merge

rm "`path_modeloutput'tmp.dta"


gen dman_base = manuf_share_base - manuf_share_no
gen dman_equal = manuf_share_equal - manuf_share_no


binscatter dman_base lnpopdensity_1939, n(100) savedata(`path_data_fig'Figure7_binscatter_dman_base) replace
rm "`path_data_fig'Figure7_binscatter_dman_base.do"
binscatter dman_equal lnpopdensity_1939, n(100) savedata(`path_data_fig'Figure7_binscatter_dman_equal) replace
rm "`path_data_fig'Figure7_binscatter_dman_equal.do"
graph drop _all
restore
********************************************************************************



********************************************************************************
** FIGURE SM_2: Wartime Destruction


* Panel 1: Density of destruction
local filename = "`path_appendix'FigureSM2a_destruction_density"


egen destroyed_houses = sum(houses_damaged)
egen houses = sum(houses_total)
gen destroyed_share_agg = destroyed_houses/houses

levelsof destroyed_share_agg, loc(agg_destr)

gr twoway (kdensity houses_sharedamaged, color(navy) lwidth(thick) /// 
xline(`agg_destr', lwidth(thick))), /// 
xtitle("Share of housing stock destroyed", size(large)) ytitle("") ///
graphregion(color(white))

gr export "`filename'.pdf", replace
drop destroyed_houses houses destroyed_share_agg


* Panel 2: Correlation with pre-war population density
local filename = "`path_appendix'FigureSM2b_destruction_popdensity_correlation"


gr twoway (scatter houses_sharedamaged lnpopdensity_1939 [w = population_1939], msymbol(smcircle_hollow) mcolor(navy)) ///
(lfit houses_sharedamaged lnpopdensity_1939, lwidth(thick)), ///
xtitle("log Population Density 1939", size(large)) ///
ytitle("Share of housing stock destroyed", size(large)) ///
graphregion(color(white)) legend(off)

gr export "`filename'.pdf", replace
********************************************************************************





********************************************************************************
*** Figure SM_3: Initial Allocation of Refugees Within and Across Counties

preserve
clear
use "`path_data'RefugeeData_VillagesBavaria.dta"

local filename = "`path_appendix'FigureSM3_initial_allocation"

*** Distribution of refugee-shares

egen mean_refugee_share_1950 = mean(refugee_share_1950)

quietly xi: reg refugee_share_1950 i.county
predict ref_res, residual
replace ref_res = ref_res + mean_refugee_share_1950

gr twoway (kdensity refugee_share_1950, color(navy) lwidth(thick)) /// 
(kdensity ref_res, color(cranberry) lwidth(thick)), /// 
xtitle("Share of refugees (1950)", size(large)) ytitle("") ///
graphregion(color(white)) ///
legend(label(1 "Unconditional distribution") label(2 "Within counties")) 
gr export "`filename'.pdf", replace

drop ref_res mean_refugee_share_1950
restore
********************************************************************************


********************************************************************************
*** Figure SM_4: Spatial Mobility Towards Urban Centers

preserve
clear
use "`path_data'RefugeeData_VillagesBavaria.dta"
local filename = "`path_appendix'FigureSM4_spatial_mobility"

binscatter refugee_share_1950 lnpopdensity_1939, n(100) absorb(county) ///
xtitle("ln pop density 1939") ytitle("Share of refugees in 1950") ///
savegraph("`filename'1950.pdf") replace

binscatter refugee_share_1961 lnpopdensity_1939, n(100) absorb(county) ///
xtitle("ln pop density 1939") ytitle("Share of refugees in 1961") ///
savegraph("`filename'1961.pdf") replace


restore
********************************************************************************



********************************************************************************
** Figure SM_5: Migration Share of outflows within states
local filename = "`path_appendix'FigureSM5_outflow_share_within"

gen outflow_share_within = outflows_withinState/outflows

egen totaloutflows_withinState = sum(outflows_withinState)
egen totaloutflows = sum(outflows)

gen Migration_share_within = totaloutflows_withinState/totaloutflows
levelsof Migration_share_within, loc(mean_within)

histogram outflow_share_within, bin(30) ///
fcolor(gs12) lcolor(gs2) ///
graphregion(color(white))  ytitle("") addplot(pci 0 `mean_within' 4 `mean_within', lcolor(gs3) lwidth(thick)  lpattern(dash)) ///
text(3.7 `mean_within' "Aggregate", place(e)) ///
xtitle("Share of outflows within the same state") legend(off)

gr export "`filename'.pdf", replace
gr drop _all
********************************************************************************

