

include("refugees_codes_builder_fcts.jl")

function construct_data(filename;full=true,subset_size=200)

    DF1=CSV.read(filename,DataFrame);
    DF1[DF1.WestGermany.==0,:countyname].="EASTGERMANY"
    DF1[DF1.WestGermany.==0,:countytype].="EASTGERMANY"
    DF1[DF1.WestGermany.==0,:state].="EASTGERMANY"
    DF1[DF1.WestGermany.==0,:pop_1939].=10948931
    DF1[DF1.WestGermany.==0,:refugee_share_1950].=0.0
    DF1[DF1.WestGermany.==0,:houses_sharedamaged].=0.0
    DF1=dropmissing(DF1);

    if full==false
        DF2=Random_Sample(DF1[DF1.WestGermany.==1,:],subset_size)
        push!(DF2,Array(DF1[DF1.WestGermany.==0,:]))
        DF_use=DF2
    else
        DF_use=DF1
    end

    DFD=select(DF_use, Not([:KREIS_ID,:countyname,:countytype,:dist_index,
                :gdp_pc_1933,:pop_1933,:pop_1939,:refugee_share_1950,
                :sA_1933,:state,:houses_sharedamaged,:WestGermany]))

    Distances=Matrix(DFD)

    Dist_length=length(DF_use.KREIS_ID)
    index_dist=(DF_use[!,:dist_index])

    Distance_Matrix=zeros(Dist_length, Dist_length)
    for i in 1:Dist_length
        Distance_Matrix[:,i]=Distances[:,index_dist[i]]
    end

    East_index=DF_use[DF_use.WestGermany.==0,:dist_index][1]
    DF_use.dist_East=DF_use[!,"distto$East_index"] 
    out=(DF=DF_use,Distance_Matrix=Distance_Matrix)
end


# Calibrate fundamentals given data and parameters
function fundamentals_restr(z,wbarguess_f, wbarguess_i, DF::DataFrame,
        Distance_Matrix;
        θ=2.0, δ=0.1, β=0.0, simulations=10, less_important_weight=0.1, switch=0,last2_weight=1.0,
        iters=1000, tol=0.1, convergence_speed=0.95, seed=123,γ=0.5, fE=1.0,σ=5.0)

        a= param(θ, z[1], 1.0,  1.0,  z[2],  z[3],  z[4],   z[5],   σ,  0.2, 0.05, 0.9, z[8], γ,  β, z[9],   δ, z[11], z[13], fE)
        @unpack  θ, χ,    ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im,    ψ,      ϵ,     σ,    α,     ɷ,    ϱ,     ρ,   γ,    β, λ, δ, η, ρ_a, fE=a

        Random.seed!(seed)
        DF_i=deepcopy(DF)
        κ=z[10]
        TradeCosts=Distance_Matrix.^(1.29/(σ-1))
        MobilityCosts=Distance_Matrix.^(κ)

        # Adjust East German GDP according to parameter
        γ_East = z[12]
        West_gdp_pc = sum(DF_i[1:end-1,:pop_1933] .* DF_i[1:end-1,:gdp_pc_1933]) / sum(DF_i[1:end-1,:pop_1933])
        DF_i[end,:gdp_pc_1933] = γ_East * West_gdp_pc # scale to Western GDP

        # Get sample length
        L=length(DF_i[!,:pop_1933])
        Data1=Data_Input_Calibration((DF_i[!,:pop_1933])./sum(DF_i[!,:pop_1933]),sum(DF_i[!,:pop_1933]),DF_i[!,:sA_1933], DF_i[!,:gdp_pc_1933])

        # Get wbar and fundamentals
        ###########
        # Feed in initial guess from no-trade-costs model
        wbar=recover_wbar(Data1, a,wbarguess_f, wbarguess_i,0)
        Fundamentals=recover_fundamentals(Data1, a, wbar,0)

        V=Fundamentals.V
        wbf=wbar.bwguess_F # returns a new guess to feed in later
        wbi=wbar.bwguess_I # returns a new guess to feed in later
        ω_I=wbar.ω_I

        a_m1=Fundamentals.Param # implied alpha to match data

        RFN1=Recover_Fundamentals_NEW(Data1, a_m1,
            wbf, wbi,
             ω_I,
            ones(L),
            V,
            TradeCosts, MobilityCosts);

        a_m=RFN1.pm

        exogV=RFN1.V.*(Data1.pop_share.^ρ_a) # Adjust for endogenous amenities

        return out=(pm=a_m,T=RFN1.T,exogV=exogV,Q=RFN1.Q,N=RFN1.N,L_I=RFN1.L_I,
            L_F=RFN1.L_F,ag_wages=RFN1.ag_wages,manuf_wages=RFN1.manuf_wages,
            TradeCosts=TradeCosts,MobilityCosts=MobilityCosts,Ψ=RFN1.Ψ,DF_i=DF_i,
            wbf=RFN1.wb_F, wbi=RFN1.wb_I)
end

function Qcube_restr(pm,Q,Time,Sims;seed=123,shocks=true)
    @unpack θ, χ, ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im, ψ, ϵ, σ, α, ɷ, ϱ, ρ, γ, β, λ, δ,η,ρ_a, fE=pm
    Random.seed!(seed)
    if shocks==true
    Shockmat=randn(length(Q),Time,Sims)
    elseif shocks==false
    Shockmat=zeros(length(Q),Time,Sims)
    end
    Qcube=zeros(length(Q),Time,Sims)
    Qcube[:,1,:]=log.(repeat(Q,1,1,Sims))
    for t in 2:Time
        Qcube[:,t,:]=(1-ϱ).* log.(repeat(Q,1,1,Sims)) .+ ϱ .* reshape(Qcube[:,t-1,:],(:,1,Sims)) .+ ɷ .*reshape(Shockmat[:,t,:],(:,1,Sims))
    end
    Qcube.=exp.(Qcube)
    return Qcube
end

function equilibrium_allocation(pm,T,V,Qcube,N, LNI::Array{Float64,1},LNF::Array{Float64,1},
        RefShare::Array{Float64,1},
        wguess_A::Array{Float64,1}, wguess_M::Array{Float64,1},
        TradeCosts::Array{Float64,2}, MobilityCosts::Array{Float64,2},
        Ψguess::Array{Float64,1};
        iters=5000, tol=0.1, convergence_speed=0.95, convergence_psi=0.5)

    @unpack θ, χ, ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im, ψ, ϵ, σ, α, ɷ, ϱ, ρ, γ, β, λ, δ,η,ρ_a, fE=pm
    Γ_θ=gamma(1-1/θ)
    L=length(T)
    Time=size(Qcube,2)
    Sims=size(Qcube,3)

    ################################################
    ######## Preallocate vectors
    ################################################

     # size of population
    sumpop=zeros(L,Time)

    # Drop Eastern Territory after WW2 (=infinite spatial frictions)
    TradeCosts_post = TradeCosts[1:end-1,1:end-1]
    MobilityCosts_post = MobilityCosts[1:end-1,1:end-1]

    Nmat=zeros(L, Time+1,Sims)
    Nmat[:,1,:]=repeat(deepcopy(N),1,1,Sims)

    LNImat=zeros(L, Time+1,Sims)
    LNImat[:,1,:]=repeat(deepcopy(LNI),1,1,Sims)

    LNFmat=zeros(L, Time+1,Sims)
    LNFmat[:,1,:]=repeat(deepcopy(LNF),1,1,Sims)

    LRImat=zeros(L, Time+1,Sims)
    LRFmat=zeros(L, Time+1,Sims)

    Immig_shock_I=zeros(L, Time,Sims)
    Immig_shock_F=zeros(L, Time,Sims)

    Mobility=zeros(L-1,L-1,Sims)
    Inflow_Outflow_Moment=ones(Sims)

    Inflows=zeros(L-1,L-1,Sims)
    Outflows=zeros(L-1,L-1,Sims)

    Inflow_vec=zeros(L-1,Sims)
    Outflow_vec=zeros(L-1,Sims)
    Ratio=zeros(L-1,Sims)
    Sumpop_all=zeros(L-1,Sims)

    # Pre-allocate wage guess
    wamat=ones(L, Time+1,Sims)
    wmmat=ones(L, Time+1,Sims)
    wamat[:,1,:]=repeat(deepcopy(wguess_A),1,1,Sims)
    wmmat[:,1,:]=repeat(deepcopy(wguess_M),1,1,Sims)
    Ψmat=ones(L,Time+1,Sims)
    Ψmat[:,1,:]=repeat(deepcopy(Ψguess),1,1,Sims)

    for s in 1:Sims
        for t in 1:Time
            if t<=13
                NEW_Period_Wage_Clearing=Wage_Clearing_endogV(wamat[:,t,s], wmmat[:,t,s],T,V,Qcube[:,t,s], Nmat[:,t,s],LNImat[:,t,s], LNFmat[:,t,s],
                    LRImat[:,t,s], LRFmat[:,t,s],Immig_shock_I[:,t,s], Immig_shock_F[:,t,s], pm, ρ_a, η,
                    TradeCosts, MobilityCosts,Ψmat[:,t,s];
                iters=iters, tol=tol, convergence_speed=convergence_speed,convergence_psi=convergence_psi)

                @unpack  ag_wage, manuf_wage, LNI_p, LNF_p, LRI_p, LRF_p, N_firms, mi, mf,Psivec=NEW_Period_Wage_Clearing
                wamat[:,t+1,s].=ag_wage
                wmmat[:,t+1,s].=manuf_wage
                LNImat[:,t+1,s]=LNI_p
                LNFmat[:,t+1,s]=LNF_p
                LRImat[:,t+1,s]=LRI_p
                LRFmat[:,t+1,s]=LRF_p
                Nmat[:,t+1,s]=N_firms
                Ψmat[:,t+1,s]=Psivec

            elseif t>13
                NEW_Period_Wage_Clearing=Wage_Clearing_endogV(wamat[1:end-1,t,s], wmmat[1:end-1,t,s],T[1:end-1],V[1:end-1],Qcube[1:end-1,t,s], Nmat[1:end-1,t,s],LNImat[1:end-1,t,s], LNFmat[1:end-1,t,s],
                    LRImat[1:end-1,t,s], LRFmat[1:end-1,t,s],Immig_shock_I[1:end-1,t,s], Immig_shock_F[1:end-1,t,s], pm, ρ_a, η,
                    TradeCosts_post, MobilityCosts_post,Ψmat[1:end-1,t,s];
                    iters=iters, tol=tol, convergence_speed=convergence_speed,convergence_psi=convergence_psi)


                @unpack  ag_wage, manuf_wage, LNI_p, LNF_p, LRI_p, LRF_p, N_firms, mi, mf,Psivec=NEW_Period_Wage_Clearing
                wamat[1:end-1,t+1,s].=ag_wage
                wmmat[1:end-1,t+1,s].=manuf_wage
                LNImat[1:end-1,t+1,s]=LNI_p
                LNFmat[1:end-1,t+1,s]=LNF_p
                LRImat[1:end-1,t+1,s]=LRI_p
                LRFmat[1:end-1,t+1,s]=LRF_p
                Nmat[1:end-1,t+1,s]=N_firms
                Ψmat[1:end-1,t+1,s]=Psivec

                if t==14
                 Immig_shock_I[1:end-1,t+1,s]=χ.*RefShare.*(LNI_p.+LNF_p)./(ones(L-1) .-RefShare)
                 Immig_shock_F[1:end-1,t+1,s]=(1-χ).*RefShare.*(LNI_p.+LNF_p)./(ones(L-1) .-RefShare)
                end

                if t==23
                Mobility[:,:,s]=(mi.+mf)'
                end
            end

        end
    end
    # Compute outcomes
    Population=LNImat.+LRImat.+LNFmat.+LRFmat
    Ref_share=(LRImat.+LRFmat)./Population

    # Manufacturing shares
    wbarImat=(ϕ_ia .* wamat.^θ .+ ϕ_im .* wmmat.^θ).^(1/θ)
    wbarFmat=(ϕ_fa .* wamat.^θ .+ ϕ_fm .* wmmat.^θ).^(1/θ)
    LImat=LNImat.+LRImat
    LFmat=LNFmat.+LRFmat
    Manuf_share=ones(size(wbarImat)).-(LImat.*ϕ_ia.*(wamat./wbarImat).^θ.+LFmat.*ϕ_fa.*(wamat./wbarFmat).^θ)./Population
    Manuf_share_Nat=ones(size(wbarImat)).-(LNImat.*ϕ_ia.*(wamat./wbarImat).^θ.+LNFmat.*ϕ_fa.*(wamat./wbarFmat).^θ)./(LNImat.+LNFmat)
    Manuf_share_Ref=ones(size(wbarImat)).-(LRImat.*ϕ_ia.*(wamat./wbarImat).^θ.+LRFmat.*ϕ_fa.*(wamat./wbarFmat).^θ)./(LRImat.+LRFmat)
    
    # Computing GDP per capita (logs and levels)
    LI_eff=LNImat.+(η*LRImat)
    LF_eff=LNFmat.+(η*LRFmat)
    HrA = Γ_θ .* LI_eff .* ϕ_ia .* (wamat./wbarImat) .^ (θ-1) .+
            Γ_θ .* LF_eff .* ϕ_fa .* (wamat./wbarFmat) .^(θ-1)
    HrM = Γ_θ .* LI_eff .* ϕ_im .* (wmmat./wbarImat) .^(θ-1)+
           Γ_θ .* LF_eff .* ϕ_fm .* (wmmat ./wbarFmat) .^(θ-1)

    if β==0.0
        HrP=(HrM .+ fE .*(1-δ).* (Nmat).^(1-λ) )
        Index=(HrM.<(ρ .- (1-β)) ./ (1-β) .* fE .* (1-δ).*(Nmat).^(1-λ))
        HrP[Index]=(ρ / (ρ - (1-β))) .* HrM[Index]
        LnGDPpc=log.(wamat.*HrA./γ +
            wmmat.*HrP).- log.(Population)
    else
        HrP=β.*(HrM .+ fE .*(1-δ).* (Nmat).^(1-λ) )
        Index=(HrM.<(ρ .- (1-β)) ./ (1-β) .* fE .* (1-δ).*(Nmat).^(1-λ))
        HrP[Index]=(ρ*β / (ρ - (1-β))) .* HrM[Index]
        LnGDPpc=log.(wamat.*HrA./γ +
            wmmat.*HrP./β).- log.(Population)
    end
    GDPpc=exp.(LnGDPpc)

    return out=(GDPpc=GDPpc[1:end-1,:,:],LnGDPpc=LnGDPpc[1:end-1,:,:],
                Population=Population[1:end-1,:,:],Ref_share=Ref_share[1:end-1,:,:],
                Manuf_share=Manuf_share[1:end-1,:,:],Manuf_share_Nat=Manuf_share_Nat[1:end-1,:,:],
                Manuf_share_Ref=Manuf_share_Ref[1:end-1,:,:],
                Mobility=Mobility,
                LNI=LNImat[1:end-1,:,:],LRI=LRImat[1:end-1,:,:],LNF=LNFmat[1:end-1,:,:],
                LRF=LRFmat[1:end-1,:,:],wbarI=wbarImat[1:end-1,:,:],
        wbarF=wbarFmat[1:end-1,:,:],N=Nmat[1:end-1,:,:],Psi = Ψmat[1:end-1,:,:])
end




# Compute moments in data and model
function compute_moments(pm::param,DF::DataFrame,eq_output)

    GDPpc=eq_output.GDPpc
    LnGDPpc=eq_output.LnGDPpc
    Population=eq_output.Population
    Ref_share=eq_output.Ref_share
    Manuf_share=eq_output.Manuf_share
    Mobility=eq_output.Mobility
    LNI=eq_output.LNI
    LRI=eq_output.LRI
    LNF=eq_output.LNF
    LRF=eq_output.LRF
    wbarI=eq_output.wbarI
    wbarF=eq_output.wbarF

    @unpack θ, χ, ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im, ψ, ϵ, σ, α, ɷ, ϱ, ρ, γ, β, λ, δ,η,ρ_a, fE=pm
    Sims=size(GDPpc,3)
    n_moments=19
    Moment_matrix=zeros(n_moments,Sims)
    # Select years to collect data
    Data_years=[1933, 1939, 1947, 1950, 1955, 1957, 1961, 1964, 1966, 1980]
    for s in 1:Sims
        DF_m=deepcopy(DF[1:end-1,:]) # Take all locations but East
        # add unique ID
        DF_m=hcat(DF_m, axes(DF_m, 1))
        DF_m[!, :Unique_Id]=string.(DF_m[!,:x1]);

        # Add "data" to DataFrame
        for j in Data_years
            t=j-1932
            DF_m.GDPpc=GDPpc[:,t,s]
            DF_m.LnGDPpc=LnGDPpc[:,t,s]
            DF_m.Population=Population[:,t,s]
            DF_m.LnPop=log.(DF_m.Population)
            DF_m.Ref_share=Ref_share[:,t,s]
            DF_m.Manuf_share=Manuf_share[:,t,s]
            DF_m.LNI=LNI[:,t,s]
            DF_m.LRI=LRI[:,t,s]
            DF_m.LNF=LNF[:,t,s]
            DF_m.LRF=LRF[:,t,s]
            DF_m.wbarI=wbarI[:,t,s]
            DF_m.wbarF=wbarF[:,t,s]

            # Winsorize growth rates
            if j>1939
                DF_m.LnGDPpc_gr=DF_m.LnGDPpc-DF_m.LNGDPPC_Model_1933
                DF_m[!,:LnGDPpc_gr].=winsor(DF_m.LnGDPpc_gr,prop=0.02)
                DF_m.LnPop_gr=DF_m.LnPop-DF_m.log_pop_Model_1939
                DF_m[!,:LnPop_gr].=winsor(DF_m.LnPop_gr,prop=0.02)
            end

            # Renaming to index by year
            rename!(DF_m,Dict("GDPpc"=>"GDPPC_Model_$j",
                    "LnGDPpc"=>"LNGDPPC_Model_$j",
                    "Population"=>"pop_Model_$j",
                    "LnPop"=>"log_pop_Model_$j",
                    "Ref_share"=>"Refshare_Model_$j",
                    "Manuf_share"=>"sM_Model_$j",
                    "LNI"=>"LNI_Model_$j",
                    "LRI"=>"LRI_Model_$j",
                    "LNF"=>"LNF_Model_$j",
                    "LRF"=>"LRF_Model_$j",
                    "wbarI"=>"wbarI_Model_$j",
                    "wbarF"=>"wbarF_Model_$j"))

            if j>1939
                rename!(DF_m,Dict("LnGDPpc_gr" => "LNGDPPC_gr_$j",
                                    "LnPop_gr" => "LnPop_gr_$j"))
            end

        end
        # First moment: refugee/native wage ratio
        avg_ref_wage_61=η*sum(DF_m.LRI_Model_1961.*DF_m.wbarI_Model_1961.+DF_m.LRF_Model_1961.*DF_m.wbarF_Model_1961)/sum(DF_m.LRI_Model_1961.+DF_m.LRF_Model_1961)
        avg_native_wage_61=sum(DF_m.LNI_Model_1961.*DF_m.wbarI_Model_1961.+DF_m.LNF_Model_1961.*DF_m.wbarF_Model_1961)/sum(DF_m.LNI_Model_1961.+DF_m.LNF_Model_1961)
        Moment_matrix[1,s]=log(avg_ref_wage_61/avg_native_wage_61)

        # Second moment! # Ref Manuf Coef 1950
        reg1=reg(DF_m, @formula(sM_Model_1950~Refshare_Model_1950+sM_Model_1939+state+log_pop_Model_1939+dist_East))
        Moment_matrix[2, s]=coef(reg1)[2]

        # Third moment! Ref manufacturing coefficient 1961
        reg2=reg(DF_m, @formula(sM_Model_1961~Refshare_Model_1950+sM_Model_1939+state+log_pop_Model_1939+dist_East))
        Moment_matrix[3, s]=coef(reg2)[2]

        # Fourth moment! # Ref_LNGDPPC_50_Coef
         reg3=reg(DF_m, @formula(LNGDPPC_gr_1950~Refshare_Model_1950+LNGDPPC_Model_1933+log_pop_Model_1939+dist_East+state))
         Moment_matrix[4, s]=coef(reg3)[2]

        # Fifth, Second P2 moment # Ref_LNGDPPC_61_Coef
         reg4=reg(DF_m, @formula(LNGDPPC_gr_1961~Refshare_Model_1950+LNGDPPC_Model_1933+log_pop_Model_1939+dist_East+state))
         Moment_matrix[5, s]=coef(reg4)[2]

        # Sixth, population coefficient in 1950
         reg5=reg(DF_m, @formula(LnPop_gr_1950~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
         Moment_matrix[6, s]=coef(reg5)[2]

        # Seventh, population coefficient in 1961
         reg6=reg(DF_m, @formula(LnPop_gr_1961~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
         Moment_matrix[7, s]=coef(reg6)[2]

        #Eighth, First P2: Ref_Share_Cor 1955
         reg7=reg(DF_m, @formula(Refshare_Model_1955~Refshare_Model_1950+state))
         Moment_matrix[8, s]=coef(reg7)[2]

        #Ninth, First P2: Ref_Share_Cor 1961
         reg8=reg(DF_m, @formula(Refshare_Model_1961~Refshare_Model_1950+state))
         Moment_matrix[9, s]=coef(reg8)[2]

         # GDPPC/lagged regression
             Lag1= DataFrame()

          ## county names repeated!
         Lag1[!,:ID]=DF_m[!,:Unique_Id]
         Lag1[!,:ID2] =DF_m[!,:countyname]
         Lag1[!,:yold] =DF_m[!,:LNGDPPC_Model_1957]
         Lag1[!,:ynew]=DF_m[!,:LNGDPPC_Model_1961]

          Lag2= DataFrame()
         Lag2[!,:ID]=DF_m[!,:Unique_Id]
         Lag2[!,:ID2]=DF_m[!,:countyname]
         Lag2[!,:yold]=DF_m[!,:LNGDPPC_Model_1961]
         Lag2[!,:ynew]=DF_m[!,:LNGDPPC_Model_1964]

          Lag3= DataFrame()
         Lag3[!,:ID]=DF_m[!,:Unique_Id]
         Lag3[!,:ID2]=DF_m[!,:countyname]
         Lag3[!,:yold]=DF_m[!,:LNGDPPC_Model_1964]
         Lag3[!,:ynew]=DF_m[!,:LNGDPPC_Model_1966]

         Lag_all=vcat(Lag1, Lag2, Lag3)

         # Tenth, Third P2 moment
         # if switch==0
             reg9=reg(Lag_all, @formula(ynew~yold+ID))## need to fix with county id's!!!
         # else
        #      reg9=reg(Lag_all, @formula(ynew~yold+ID2))
         # end
         Moment_matrix[10, s]=coef(reg9)[2]

         # Eleventh, Fourth P2 moment
         Moment_matrix[11, s]=std(residuals(reg9, Lag_all))

         # Twelfth moment, helps ID phi_ia: manuf/ag wage ratio
         Farmers=DF_m.LNF_Model_1966.+DF_m.LRF_Model_1966
         Industrial=DF_m.LNI_Model_1966.+DF_m.LRI_Model_1966

         ybar_m=(DF_m.wbarF_Model_1966.^(1-θ).*ϕ_fm.*Farmers.+DF_m.wbarI_Model_1966.^(1-θ).*ϕ_im.*Industrial)./
         (ϕ_fm.*DF_m.wbarF_Model_1966.^(0-θ).*Farmers.+ϕ_im.*DF_m.wbarI_Model_1966.^(0-θ).*Industrial)

         ybar_a=(DF_m.wbarF_Model_1966.^(1-θ).*ϕ_fa.*Farmers.+DF_m.wbarI_Model_1966.^(1-θ).*ϕ_ia.*Industrial)./
         (ϕ_fa.*DF_m.wbarF_Model_1966.^(0-θ).*Farmers.+ϕ_ia.*DF_m.wbarI_Model_1966.^(0-θ).*Industrial)

         Moment_matrix[12, s]=mean(ybar_m./ybar_a)

         # Thirteenth moment: ratio of inflows to outflows for counties with negative net flows
         # Note that this is in 1955
         Outflows=copy(Mobility[:,:,s])
         Inflows=copy(Outflows')
         Inflows[diagind(Inflows)]=zeros(size(Inflows,1))
         Outflows[diagind(Outflows)]=zeros(size(Outflows,1))
         Inflow_vec=sum(Inflows,dims=2)
         Outflow_vec=sum(Outflows,dims=2)
         Ratio=dropdims(Inflow_vec./Outflow_vec; dims=2)
         Datanew=DataFrame(Ratio=Ratio,Pop=DF_m.pop_Model_1955)
         Datanew=Datanew[Datanew.Ratio.<1,:]
         Datanew.weighted=Datanew.Ratio.*Datanew.Pop
         Moment_matrix[13,s]=sum(Datanew.weighted)./sum(Datanew.Pop)

         # Fourteenth moment: share of outflows within own state
             Mobility_T=copy(Mobility[:,:,s]')
             DFN=deepcopy(DF_m)
             DFN2=deepcopy(DF_m)
             select!(DFN2, [:state])

             DFN[!,:ownflow].=0.0 # stores diagonal
             DFN[!,:own_state_outflow].=0.0
             DFN[!,:outflow].=0.0

             for i in 1:size(Mobility_T,1)
                 x=[DFN.dist_index[i]]
                 insertcols!(DFN2,ncol(DFN2)+1, :z2 => Mobility_T[:,i]);
                 rename!(DFN2, Dict(:z2 => Symbol(x[1])))
                 DFN.ownflow[i]=Mobility_T[i,i]
             end

             DFN3=combine(groupby(DFN2,:state,sort=false,skipmissing=false),names(DFN2,Not(:state)).=>sum) #summarize outflows by state--row is destination state, column is sending county

             for i in 1:size(Mobility_T,1)
                 for j in 1:length(DFN3[:,:state])
                     if DFN[i,:state]==DFN3[j,:state]
                         DFN[i,:own_state_outflow]=DFN3[j,i+1]
                     end
                 end
                 DFN[i,:outflow]=sum(DFN3[:,i+1])
             end

         DFN.own_state_outflow.=DFN.own_state_outflow.-DFN.ownflow
         DFN.outflow.=DFN.outflow.-DFN.ownflow;
         Moment_matrix[14, s]=(sum(DFN.own_state_outflow)./sum(DFN.outflow))

         # Fifteenth moment: distance regression
          reg10 = reg(DF_m,@formula(LNGDPPC_Model_1961~Refshare_Model_1950+dist_East+LNGDPPC_Model_1933+log_pop_Model_1939+state))
          Moment_matrix[15,s]=coef(reg10)[3]

         # Population growth 1950-1955 and 1955-1961
         DF_m.pop_gr_50_55 = DF_m.log_pop_Model_1955-DF_m.log_pop_Model_1950
         DF_m[!,:pop_gr_50_55].=winsor(DF_m.pop_gr_50_55,prop=0.02)
         DF_m.pop_gr_55_61 = DF_m.log_pop_Model_1961-DF_m.log_pop_Model_1955
         DF_m[!,:pop_gr_55_61].=winsor(DF_m.pop_gr_55_61,prop=0.02)

         # Sixteenth moment: 50-55 pop growth on refshare coefficient
         reg11 = reg(DF_m,@formula(pop_gr_50_55~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
         Moment_matrix[16,s]=coef(reg11)[2]

         # Seventeenth moment: same for 55-61
         reg12 = reg(DF_m,@formula(pop_gr_55_61~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
         Moment_matrix[17,s]=coef(reg12)[2]

         # Eighteenth moment: 1980 log GDPpc on refugees
         reg13 = reg(DF_m,@formula(LNGDPPC_gr_1980~Refshare_Model_1950+LNGDPPC_Model_1933+log_pop_Model_1939+dist_East+state))
         Moment_matrix[18,s]=coef(reg13)[2]

         # Nineteenth moment: 1980 log population on refugees
         reg14 = reg(DF_m,@formula(LnPop_gr_1980~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
         Moment_matrix[19,s]=coef(reg14)[2]
    end
    Moment_vector=mean(Moment_matrix,dims=2)
    out=(Moment_vector=Moment_vector)
end




function make_analysis_data(pm::param,DF::DataFrame,eq_output,filename)
    @unpack θ, χ, ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im, ψ, ϵ, σ, α, ɷ, ϱ, ρ, γ, β, λ, δ,η,ρ_a, fE=pm
    # Initialize data frame
    model_data=DataFrame(KREIS_ID=DF[1:end-1,:KREIS_ID],
                            countyname=DF[1:end-1,:countyname],
                            countytype=DF[1:end-1,:countytype],
                            state=DF[1:end-1,:state],
                            dist_index=DF[1:end-1,:dist_index])
    # Add simulated data
    GDPpc=mean(eq_output.GDPpc,dims=3)
    GDPyrs=[1933,1950,1961]
    for j in GDPyrs
        t=j-1932
        model_data.GDPpc=GDPpc[:,t]
        rename!(model_data,Dict("GDPpc" => "GDPPC_Model_$j"))
    end
    Manuf_share=mean(eq_output.Manuf_share,dims=3)
    Manuf_share_Nat=mean(eq_output.Manuf_share_Nat,dims=3)
    Manuf_share_Ref=mean(eq_output.Manuf_share_Ref,dims=3)
    Manuf_share_yrs=[1939,1950,1961]
    for j in Manuf_share_yrs
        t=j-1932
        model_data.Manuf_share=Manuf_share[:,t]
        model_data.Manuf_share_Nat=Manuf_share_Nat[:,t]
        model_data.Manuf_share_Ref=Manuf_share_Ref[:,t]
        rename!(model_data,Dict("Manuf_share" => "Manuf_Share_Model_$j",
                                "Manuf_share_Nat" => "Manuf_Share_Nat_Model_$j",
                                "Manuf_share_Ref" => "Manuf_Share_Ref_Model_$j"))
    end
    pop=mean(eq_output.Population,dims=3)
    pop_yrs=[1933,1939,1950,1955,1961]
    for j in pop_yrs
        t=j-1932
        model_data.pop=pop[:,t]
        rename!(model_data,Dict("pop" => "pop_Model_$j"))
    end
    Refshare=mean(eq_output.Ref_share,dims=3)
    Refshare_yrs=[1950,1955,1961]
    for j in Refshare_yrs
        t=j-1932
        model_data.Refshare=Refshare[:,t]
        rename!(model_data,Dict("Refshare" => "Refshare_Model_$j"))
    end
    N=mean(eq_output.N,dims=3)
    N_yrs=[1946,1947,1948,1949,1950,1955,1961]
    for j in N_yrs
        t=j-1932
        model_data.N=N[:,t]
        rename!(model_data,Dict("N" => "N_Model_$j"))
    end
    ind_cube=eq_output.LNI./(eq_output.LNI.+eq_output.LNF)
    ind=mean(ind_cube,dims=3)
    model_data.ind_share_Model_1933=ind[:,1]

    # Mobility outcomes
    Outflows=copy(dropdims(mean(eq_output.Mobility,dims=3),dims=3))
    Inflows=copy(Outflows')
    Inflows[diagind(Inflows)]=zeros(size(Inflows,1))
    Outflows[diagind(Outflows)]=zeros(size(Outflows,1))
    Inflow_vec=dropdims(sum(Inflows,dims=2),dims=2)
    Outflow_vec=dropdims(sum(Outflows,dims=2),dims=2)
    model_data.Inflows_Model_55=Inflow_vec
    model_data.Outflows_Model_55=Outflow_vec

    # Share of outflows within own state
        Mobility_T=copy(dropdims(mean(eq_output.Mobility,dims=3),dims=3)')
        DFN=deepcopy(model_data)
        DFN2=deepcopy(model_data)
        select!(DFN2, [:state])

        DFN[!,:ownflow].=0.0 # stores diagonal
        DFN[!,:own_state_outflow].=0.0
        DFN[!,:outflow].=0.0

        for i in 1:size(Mobility_T,1)
            x=[DFN.dist_index[i]]
            insertcols!(DFN2,ncol(DFN2)+1, :z2 => Mobility_T[:,i]);
            rename!(DFN2, Dict(:z2 => Symbol(x[1])))
            DFN.ownflow[i]=Mobility_T[i,i]
        end

        DFN3=combine(groupby(DFN2,:state,sort=false,skipmissing=false),names(DFN2,Not(:state)).=>sum) #summarize outflows by state--row is destination state, column is sending county

        for i in 1:size(Mobility_T,1)
            for j in 1:length(DFN3[:,:state])
                if DFN[i,:state]==DFN3[j,:state]
                    DFN[i,:own_state_outflow]=DFN3[j,i+1]
                end
            end
            DFN[i,:outflow]=sum(DFN3[:,i+1])
        end

    DFN.own_state_outflow.=DFN.own_state_outflow.-DFN.ownflow
    model_data.Own_State_Outflows_Model=DFN.own_state_outflow
    CSV.write(filename,model_data)
    
end

function scale_effects(pm::param,DF::DataFrame,eq_output,filename)

    LnGDPpc=eq_output.LnGDPpc
    Population=eq_output.Population
    Ref_share=eq_output.Ref_share

    @unpack θ, χ, ϕ_fa, ϕ_fm, ϕ_ia, ϕ_im, ψ, ϵ, σ, α, ɷ, ϱ, ρ, γ, β, λ, δ,η,ρ_a, fE=pm
    Sims=size(LnGDPpc,3)
    startyear=1950
    endyear=size(LnGDPpc,2)+1932
    series_length=size(LnGDPpc,2)-(startyear-1933)

    GDP_coeff_mat=zeros(series_length,Sims)
    Pop_coeff_mat=zeros(series_length,Sims)

    GDP_sd_mat=zeros(series_length,Sims)
    Pop_sd_mat=zeros(series_length,Sims)

    # Select years to collect data
    Data_years=cat([1933,1939],startyear:endyear,dims=(1,1))
    for s in 1:Sims
        DF_m=deepcopy(DF[1:end-1,:]) # Take all locations but East
        # add unique ID
        DF_m=hcat(DF_m, axes(DF_m, 1))
        DF_m[!, :Unique_Id]=string.(DF_m[!,:x1]);

        # Add "data" to DataFrame
        for j in Data_years
            t=j-1932
            if j==1950
                DF_m.Refshare_Model_1950=Ref_share[:,t,s]
            end
            DF_m.LnGDPpc=LnGDPpc[:,t,s]
            DF_m.Population=Population[:,t,s]
            DF_m.LnPop=log.(DF_m.Population)

                   # Winsorize growth rates
            if j>1939
            DF_m.LnGDPpc_gr=DF_m.LnGDPpc-DF_m.LNGDPPC_Model_1933
            DF_m[!,:LnGDPpc_gr].=winsor(DF_m.LnGDPpc_gr,prop=0.02)
            DF_m.LnPop_gr=DF_m.LnPop-DF_m.log_pop_Model_1939
            DF_m[!,:LnPop_gr].=winsor(DF_m.LnPop_gr,prop=0.02)
            end

            if j < 1950
                # Renaming to index by year
                rename!(DF_m,Dict("LnGDPpc"=>"LNGDPPC_Model_$j",
                        "Population"=>"pop_Model_$j",
                        "LnPop"=>"log_pop_Model_$j"))
            else
                GDPreg=reg(DF_m,@formula(LnGDPpc_gr~Refshare_Model_1950+LNGDPPC_Model_1933+log_pop_Model_1939+dist_East+state))
                Popreg=reg(DF_m,@formula(LnPop_gr~Refshare_Model_1950+log_pop_Model_1939+dist_East+state))
                GDP_coeff_mat[j-startyear+1,s]=coef(GDPreg)[2]
                Pop_coeff_mat[j-startyear+1,s]=coef(Popreg)[2]

                GDP_sd_mat[j-startyear+1,s] = stderror(GDPreg)[2]
                Pop_sd_mat[j-startyear+1,s] = stderror(Popreg)[2]
            end

        end

    end
    GDP_coeff_vec=mean(GDP_coeff_mat,dims=2)
    Pop_coeff_vec=mean(Pop_coeff_mat,dims=2)

    GDP_sd_vec=mean(GDP_sd_mat,dims=2)
    Pop_sd_vec=mean(Pop_sd_mat,dims=2)

    out=(GDP_coeff=GDP_coeff_vec,Pop_coeff=Pop_coeff_vec, GDP_sd = GDP_sd_vec, Pop_sd = Pop_sd_vec)

    year_vec = Data_years[3:end];
    ScaleCoefficientsDF = DataFrame(year = year_vec);
    ScaleCoefficientsDF.gdp = out.GDP_coeff[:,1];
    ScaleCoefficientsDF.pop = out.Pop_coeff[:,1];
    ScaleCoefficientsDF.gdp_sd = out.GDP_sd[:,1];
    ScaleCoefficientsDF.pop_sd = out.Pop_sd[:,1];


    CSV.write(filename,ScaleCoefficientsDF)
end

function calculate_distance(True_Moments,Sim_Moments,weights)
    Distance=weights[1]*ASD(Sim_Moments.Ref_Wage_Ratio_log, True_Moments.Ref_Wage_Ratio_log)+
    weights[2]*ASD(Sim_Moments.Ref_manu_gr_50, True_Moments.Ref_manu_gr_50)+
    weights[3]*ASD(Sim_Moments.Ref_manu_gr_61, True_Moments.Ref_manu_gr_61)+
    weights[4]*ASD(Sim_Moments.Ref_GDP_gr_50, True_Moments.Ref_GDP_gr_50)+
    weights[5]*ASD(Sim_Moments.Ref_GDP_gr_61,   True_Moments.Ref_GDP_gr_61)+
    weights[6]*ASD(Sim_Moments.Ref_pop_gr_50,   True_Moments.Ref_pop_gr_50)+
    weights[7]*ASD(Sim_Moments.Ref_pop_gr_61,   True_Moments.Ref_pop_gr_61)+
    weights[8]*ASD(Sim_Moments.Ref_sh_cor_50,   True_Moments.Ref_sh_cor_50)+
    weights[9]*ASD(Sim_Moments.Ref_sh_cor_61,   True_Moments.Ref_sh_cor_61)+
    weights[10]*ASD(Sim_Moments.GDP_lag_coef,   True_Moments.GDP_lag_coef)+
    weights[11]*ASD(Sim_Moments.GDP_lag_sd,   True_Moments.GDP_lag_sd)+
    weights[12]*SSD(Sim_Moments.Manuf_Ag_WageRatio, True_Moments.Manuf_Ag_WageRatio)+
    weights[13]*SSD(Sim_Moments.In_Out_Flow_Ratio, True_Moments.In_Out_Flow_Ratio)+
    weights[14]*SSD(Sim_Moments.Mobility_Distance, True_Moments.Mobility_Distance)+
    weights[15]*ASD(Sim_Moments.Distance_coef, True_Moments.Distance_coef)+
    weights[16]*ASD(Sim_Moments.Ref_pop_gr_50_55, True_Moments.Ref_pop_gr_50_55)+
    weights[17]*ASD(Sim_Moments.Ref_pop_gr_55_61, True_Moments.Ref_pop_gr_55_61)+
    weights[18]*ASD(Sim_Moments.Ref_GDP_gr_80, True_Moments.Ref_GDP_gr_80)+
    weights[19]*(Sim_Moments.pop_coef_80>True_Moments.pop_coef_80_UB)+
    weights[20]*ASD(Sim_Moments.pop_coef_80, True_Moments.Ref_pop_gr_80)
end

function export_moments(True_Moments,moments_out, filename)

    Target_Moments=(
            Ref_pop_gr_50=True_Moments.Ref_pop_gr_50,
            Ref_pop_gr_61=True_Moments.Ref_pop_gr_61,
            Ref_pop_gr_80=True_Moments.Ref_pop_gr_80,
            Ref_y_gr_50=True_Moments.Ref_GDP_gr_50,
            Ref_y_gr_61=True_Moments.Ref_GDP_gr_61,
            Ref_y_gr_80=True_Moments.Ref_GDP_gr_80,
            Ref_manu_gr_50=True_Moments.Ref_manu_gr_50,
            Ref_manu_gr_61=True_Moments.Ref_manu_gr_61,
            Ref_sh_cor_55=True_Moments.Ref_sh_cor_50,
            Ref_sh_cor_61=True_Moments.Ref_sh_cor_61,
            Ref_pop_gr_50_55=True_Moments.Ref_pop_gr_50_55,
            Distance_marketaccess=True_Moments.Distance_coef,
            Stddev_y_residuals=True_Moments.GDP_lag_sd,
            Earnings_differential=True_Moments.Ref_Wage_Ratio_log,
            Agric_prod_gap=True_Moments.Manuf_Ag_WageRatio,
            Outflow_share=True_Moments.Mobility_Distance,
            );

Model_Moments = [
    moments_out[6],
    moments_out[7],
    moments_out[19],
    moments_out[4],
    moments_out[5],
    moments_out[18],
    moments_out[2],
    moments_out[3],
    moments_out[8],
    moments_out[9],
    moments_out[16],
    moments_out[15],
    moments_out[11],
    moments_out[1],
    moments_out[12],
    moments_out[14]];

Moment_Table =hcat(collect(keys(Target_Moments)),collect(Target_Moments),collect(Model_Moments));
MomentsDF = DataFrame(Moment = Moment_Table[:,1], Data = Moment_Table[:,2], Model = Moment_Table[:,3]);
CSV.write(filename,MomentsDF);

end

function export_params(pm::param, filename)

model_parameters = (
    lambda = round(pm.λ, digits=3),
    rho = round(pm.ρ, digits=3),
    epsilon = round(pm.ϵ, digits=3),
    psi = round(pm.ψ, digits=3),
    beta = round(pm.ρ_a, digits=3),
    varpi = round(pm.ɷ, digits=3),
    varrho = round(pm.ϱ, digits=3),
    chi =  round(pm.χ, digits=3),
    phi_IA = round(pm.ϕ_ia, digits=3),
    phi_IM = round(pm.ϕ_im, digits=3),
    theta = round(pm.θ, digits=3),
    alpha =  round(pm.α, digits=3),
    sigma = round(pm.σ, digits=3),
    gamma = round(pm.γ, digits=3),
    delta = round(pm.δ, digits=3));

Parameter_Table =hcat(collect(keys(model_parameters)),collect(model_parameters));
ParametersDF = DataFrame(Parameter = Parameter_Table[:,1], Value = Parameter_Table[:,2])
CSV.write(filename,ParametersDF);

end


function identification(Param,Data_in, filename)
    
Len=size(Data_in.DF,1)
    
RangeSize = 5; 
NumParams = 4;    
    
IdMoments = zeros(RangeSize,NumParams) 
IdParams = zeros(RangeSize,NumParams)
EstimatedParams = zeros(1,NumParams)   
    
 for k = 1:NumParams    
    
    # Identification 1: Lambda
    if k == 1     
    pm_index = 9;       
    param_vector = LinRange(0.6, 0.8, RangeSize) 
    moment_index = 5;     
    end
     
    # Identification 2: rho    
    if k == 2
    param_vector = LinRange(3.5, 8, RangeSize)  
    pm_index = 8;
    moment_index = 4; 
    end
     
    # Identification 3: psi     
    if k == 3
    param_vector = LinRange(0.02, 0.4, RangeSize)  
    pm_index = 4;
    moment_index = 9; 
    end
        
    # Identification 4: epsilon  
    if k == 4
    param_vector = LinRange(1.1, 3, RangeSize)  
    pm_index = 5;
    moment_index = 16; 
    end    
        
    EstimatedParams[k] = Param[pm_index]; 
        
    for j = 1:RangeSize
    
    IdParams[j,k] = param_vector[j];     
        
    Param_id = copy(Param);
    Param_id[pm_index] =  param_vector[j];
        
    eq_inputs=fundamentals_restr(Param_id,ones(Len),ones(Len),Data_in.DF,Data_in.Distance_Matrix); 
    Q_input=Qcube_restr(eq_inputs.pm,eq_inputs.Q,48,1; shocks = false)   ;
        
    eq_output=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
    Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
    Data_in.DF[1:end-1,:refugee_share_1950],
    eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
    eq_inputs.MobilityCosts,eq_inputs.Ψ);
        
    moments_out=compute_moments(eq_inputs.pm,Data_in.DF,eq_output);   
        
    IdMoments[j,k] = moments_out[moment_index];   
           
    end
        
 end
    
    
ParameterDF = DataFrame(lambda = IdParams[:,1]);
    ParameterDF.rho = IdParams[:,2];
    ParameterDF.psi = IdParams[:,3];
    ParameterDF.epsilon = IdParams[:,4];
    
MomentDF = DataFrame(lambda = IdMoments[:,1]);    
    MomentDF.rho = IdMoments[:,2];
    MomentDF.psi = IdMoments[:,3];
    MomentDF.epsilon = IdMoments[:,4];
 
EstimatesDF =  DataFrame(est = EstimatedParams[1,:]);  
    
CSV.write("$(filename)_parameters.csv",ParameterDF);
CSV.write("$(filename)_moments.csv",MomentDF);
CSV.write("$(filename)_estimated_parameters.csv",EstimatesDF);
            
end




function long_run_implications(eq_inputs,DF,model,path;sims=50,end_yr=2200)
    
    pm=eq_inputs.pm
    Q=eq_inputs.Q
    Time=end_yr-1932
    
    # Q_matrix with shocks
    num_period_shocks = 1970 - 1932;
    num_period_no_shocks = end_yr - 1970;
    
    Q_shocks=Qcube_restr(pm,Q,num_period_shocks,sims; shocks = true)
    Q_no_shocks=Qcube_restr(pm,Q,num_period_no_shocks,sims; shocks = false)
    
    Q_input= cat(Q_shocks,Q_no_shocks,dims = 2);    
    
    
    # Allocations with refugees
    println("Begin simulations with refugees")
    eq_output_Refs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        DF[1:end-1,:refugee_share_1950],
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    
    # Allocations without refugees
    println("Begin simulations without refugees")
    eq_output_noRefs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        zeros(size(DF,1)-1),
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
  
    
##### Long-run dispersion measures of model with particular sample paths
upquant = 0.9; lowquant = 0.1;

     
T = length(eq_output_Refs.Ref_share[1,:,1]);  
Sim = length(eq_output_Refs.Ref_share[1,1,:]);
    
disp_ref_share = zeros(T,Sim);
disp_y_growth = zeros(T,Sim);  
disp_pop_growth = zeros(T,Sim);     
    
for s = 1:Sim    
for j = 1:(T-1)
# Refugee shares     
disp_ref_share[j,s] = quantile(eq_output_Refs.Ref_share[:,j,s],upquant) - quantile(eq_output_Refs.Ref_share[:,j,s],lowquant);
    
ygr = eq_output_Refs.LnGDPpc[:,j+1,s] - eq_output_Refs.LnGDPpc[:,j,s];     
disp_y_growth[j,s] =  quantile(ygr,upquant); 
        
popgr = log.(eq_output_Refs.Population[:,j+1,s]) - log.(eq_output_Refs.Population[:,j,s]);     
disp_pop_growth[j,s] =  quantile(popgr,upquant);           
    end
end

   
Year = collect(1:T)
spatial_disperion=DataFrame(time=Year);

for s in 1:Sim
    spatial_disperion.RefShare = disp_ref_share[:,s];
    spatial_disperion.disp_y_growth = disp_y_growth[:,s];
    spatial_disperion.disp_pop_growth = disp_pop_growth[:,s];
    rename!(spatial_disperion,Dict("RefShare" => "RefShare_sim_$s"))
    rename!(spatial_disperion,Dict("disp_y_growth" => "disp_y_growth_sim_$s"))
    rename!(spatial_disperion,Dict("disp_pop_growth" => "disp_pop_growth_sim_$s"))
end
    

CSV.write("$(path)SM8_spatial_disperion_$(model).csv",spatial_disperion)
    
    
R = length(eq_output_Refs.Ref_share[:,1,1]);
lnpop = log.(eq_output_Refs.Population)    
    
xsec_pop_disp = zeros(R, 2)  
    for r = 1:R
        xsec_pop_disp[r,1] = quantile(lnpop[r,num_period_shocks,:],upquant) - quantile(lnpop[r,num_period_shocks,:],lowquant)
        xsec_pop_disp[r,2] = quantile(lnpop[r,end,:],upquant) - quantile(lnpop[r,end,:],lowquant)
    end

county = collect(1:R)
spatial_path_dep = DataFrame(county=county);    
spatial_path_dep.dispSR = xsec_pop_disp[:,1];
spatial_path_dep.dispLR = xsec_pop_disp[:,2];
    
CSV.write("$(path)SM9_pathdep_$(model).csv",spatial_path_dep)


    
##### Aggregate output effect  
agg_GDPpc_Refs=sum(eq_output_Refs.GDPpc.*eq_output_Refs.Population,dims=1)./sum(eq_output_Refs.Population,dims=1)
agg_GDPpc_noRefs=sum(eq_output_noRefs.GDPpc.*eq_output_noRefs.Population,dims=1)./sum(eq_output_noRefs.Population,dims=1)

agg_GDPpc_diff=dropdims((agg_GDPpc_Refs.-agg_GDPpc_noRefs)./agg_GDPpc_noRefs,dims=1) # Will have size Time x sims
    println(size(agg_GDPpc_diff))
    # Now create dataframe
    agg_output=DataFrame(Year=1933:end_yr)
    println(size(agg_output))
    for s in 1:sims
        agg_output.GDPpc_diff=agg_GDPpc_diff[2:end,s]
        rename!(agg_output,Dict("GDPpc_diff" => "GDPPC_Change_Sim_$s"))
    end
    
CSV.write("$(path)SM9_agg_output_$(model).csv",agg_output)

    return agg_output
end



function agg_implications(eq_inputs,filename,DF;sims=50,end_yr=2000)
    println("Begin aggregate implications")
    pm=eq_inputs.pm
    Q=eq_inputs.Q
    Time=end_yr-1932
    Q_input=Qcube_restr(pm,Q,Time,sims)
    println("Begin simulations with refugees")
    eq_output_Refs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        DF[1:end-1,:refugee_share_1950],
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    println("Begin simulations without refugees")
    eq_output_noRefs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        zeros(size(DF,1)-1),
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
   
#(1) Calculate aggregate GDP effect as nominal growth rates
agg_GDPpc_Refs=sum(eq_output_Refs.GDPpc.*eq_output_Refs.Population,dims=1)./sum(eq_output_Refs.Population,dims=1)
agg_GDPpc_noRefs=sum(eq_output_noRefs.GDPpc.*eq_output_noRefs.Population,dims=1)./sum(eq_output_noRefs.Population,dims=1)

agg_GDPpc_diff=dropdims((agg_GDPpc_Refs.-agg_GDPpc_noRefs)./agg_GDPpc_noRefs,dims=1) # Will have size Time x sims
    
println(size(agg_GDPpc_diff))
    
#(2) Calculate aggregate GDP effect as spending-weighted local real GDP growth rates 
realGDPpc_ref = eq_output_Refs.GDPpc[:,:,:] ./ eq_output_Refs.Psi[:,:,:];
realGDPpc_noref = eq_output_noRefs.GDPpc[:,:,:] ./ eq_output_noRefs.Psi[:,:,:];
d_gdp = log.(realGDPpc_ref) - log.(realGDPpc_noref);

TotSpending = eq_output_Refs.GDPpc[:,:,:].*eq_output_Refs.Population[:,:,:];
spending_share = TotSpending./sum(TotSpending, dims = 1);
agg_GDPpc_diff_chain = dropdims(sum(d_gdp.*spending_share, dims = 1), dims = 1);
  
    
# Now create dataframes
agg_output=DataFrame(Year=1933:end_yr)
    println(size(agg_output))
    for s in 1:sims
        agg_output.GDPpc_diff=agg_GDPpc_diff[2:end,s]
        rename!(agg_output,Dict("GDPpc_diff" => "GDPPC_Change_Sim_$s"))
    end
    #CSV.write("Model_Data/Final_Output/$(filename).csv",agg_output)
    CSV.write(filename,agg_output)
    
agg_output_chain=DataFrame(Year=1933:end_yr) 
    for s in 1:sims
        agg_output_chain.GDPpc_diff=agg_GDPpc_diff_chain[2:end,s]
        rename!(agg_output_chain,Dict("GDPpc_diff" => "GDPPC_Change_chain_Sim_$s"))
    end
    #CSV.write("Model_Data/Final_Output/$(filename)_chain.csv",agg_output_chain)    
    
    
    return agg_output
end

function spatial_implications(eq_inputs,filename,DF;sims=50)
    println("Begin spatial implications")
    pm=eq_inputs.pm
    Q=eq_inputs.Q
    Time=29
    Q_input=Qcube_restr(pm,Q,Time,sims)
    println("Begin simulations with refugees")
    eq_output_Refs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        DF[1:end-1,:refugee_share_1950],
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    println("Begin simulations without refugees")
    eq_output_noRefs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        zeros(size(DF,1)-1),
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    # Create data frame
    spatial_output=DataFrame(KREIS_ID=DF[1:end-1,:KREIS_ID],
                            countyname=DF[1:end-1,:countyname],
                            state=DF[1:end-1,:state],
                            refugee_share_1950_DATA=DF[1:end-1,:refugee_share_1950])
    for s in 1:sims
        for j in [1950,1961]
            t=j-1932
            spatial_output.y_withref=eq_output_Refs.GDPpc[:,t,s]
            spatial_output.N_withref=eq_output_Refs.N[:,t,s]
            spatial_output.pop_withref=eq_output_Refs.Population[:,t,s]
            spatial_output.manuf_share_withref=eq_output_Refs.Manuf_share[:,t,s]
            spatial_output.ref_share_MODEL=eq_output_Refs.Ref_share[:,t,s]
            spatial_output.y_noref=eq_output_noRefs.GDPpc[:,t,s]
            spatial_output.N_noref=eq_output_noRefs.N[:,t,s]
            spatial_output.pop_noref=eq_output_noRefs.Population[:,t,s]
            spatial_output.manuf_share_noref=eq_output_noRefs.Manuf_share[:,t,s]
            rename!(spatial_output,Dict("y_withref" => "y_withref_$(j)_sim_$s",
                                        "N_withref" => "N_withref_$(j)_sim_$s",
                                        "pop_withref" => "pop_withref_$(j)_sim_$s",
                                        "manuf_share_withref" => "manuf_share_withref_$(j)_sim_$s",
                                        "ref_share_MODEL" => "ref_share_MODEL_$(j)_sim_$s",
                                        "y_noref" => "y_noref_$(j)_sim_$s",
                                        "N_noref" => "N_noref_$(j)_sim_$s",
                                        "pop_noref" => "pop_noref_$(j)_sim_$s",
                                        "manuf_share_noref" => "manuf_share_noref_$(j)_sim_$s"))
        end
    end

    CSV.write(filename,spatial_output)
    return spatial_output
end

function supply_demand(eq_inputs,filename,DF)
    println("Begin supply and demand")
    pm=eq_inputs.pm
    Q=eq_inputs.Q
    Time=29
    Q_input=Qcube_restr(pm,Q,Time,1)
    eq_output_Refs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        DF[1:end-1,:refugee_share_1950],
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    eq_output_noRefs=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        zeros(size(DF,1)-1),
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    # Initialize dataframe
    sd_output=DataFrame(KREIS_ID=DF[1:end-1,:KREIS_ID],
                            countyname=DF[1:end-1,:countyname],
                            state=DF[1:end-1,:state],
                            refugee_share_1950_DATA=DF[1:end-1,:refugee_share_1950])
    sd_output.DMan_50_r_l_full=eq_output_Refs.Manuf_share[:,18,1]-eq_output_noRefs.Manuf_share[:,18,1]
    sd_output.DMan_61_r_l_full=eq_output_Refs.Manuf_share[:,29,1]-eq_output_noRefs.Manuf_share[:,29,1]
    sd_output.Dy_1950_r_l_full=eq_output_Refs.LnGDPpc[:,18,1]-eq_output_noRefs.LnGDPpc[:,18,1]
    sd_output.Dy_1961_r_l_full=eq_output_Refs.LnGDPpc[:,29,1]-eq_output_noRefs.LnGDPpc[:,29,1]
    # Initialize some placeholders
    sd_output.DMan_50_r_l_supply=zeros(size(DF,1)-1)
    sd_output.DMan_61_r_l_supply=zeros(size(DF,1)-1)
    sd_output.Dy_1950_r_l_supply=zeros(size(DF,1)-1)
    sd_output.Dy_1961_r_l_supply=zeros(size(DF,1)-1)
    sd_output.DMan_50_r_l_demand=zeros(size(DF,1)-1)
    sd_output.DMan_61_r_l_demand=zeros(size(DF,1)-1)
    sd_output.Dy_1950_r_l_demand=zeros(size(DF,1)-1)
    sd_output.Dy_1961_r_l_demand=zeros(size(DF,1)-1)
    for k in 1:size(DF,1)-1
        println("On region $k")
        ref_cf_S=zeros(size(DF,1)-1)
        ref_cf_S[k]=DF[k,:refugee_share_1950]
        ref_cf_D=DF[1:end-1,:refugee_share_1950]
        ref_cf_D[k]=0.0
        eq_output_S=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
            Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
            ref_cf_S,
            eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
            eq_inputs.MobilityCosts,eq_inputs.Ψ)
        eq_output_D=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
            Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
            ref_cf_D,
            eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
            eq_inputs.MobilityCosts,eq_inputs.Ψ)
        sd_output[k,:DMan_50_r_l_supply]=eq_output_S.Manuf_share[k,18,1]-eq_output_noRefs.Manuf_share[k,18,1]
        sd_output[k,:DMan_61_r_l_supply]=eq_output_S.Manuf_share[k,29,1]-eq_output_noRefs.Manuf_share[k,29,1]
        sd_output[k,:Dy_1950_r_l_supply]=eq_output_S.LnGDPpc[k,18,1]-eq_output_noRefs.LnGDPpc[k,18,1]
        sd_output[k,:Dy_1961_r_l_supply]=eq_output_S.LnGDPpc[k,29,1]-eq_output_noRefs.LnGDPpc[k,29,1]
        sd_output[k,:DMan_50_r_l_demand]=eq_output_D.Manuf_share[k,18,1]-eq_output_noRefs.Manuf_share[k,18,1]
        sd_output[k,:DMan_61_r_l_demand]=eq_output_D.Manuf_share[k,29,1]-eq_output_noRefs.Manuf_share[k,29,1]
        sd_output[k,:Dy_1950_r_l_demand]=eq_output_D.LnGDPpc[k,18,1]-eq_output_noRefs.LnGDPpc[k,18,1]
        sd_output[k,:Dy_1961_r_l_demand]=eq_output_D.LnGDPpc[k,29,1]-eq_output_noRefs.LnGDPpc[k,29,1]
    end

    CSV.write(filename,sd_output)
    return sd_output
end



function allocation_cf(eq_inputs, filename, DF; end_yr = 2000)
    println("Begin allocation counterfactual")
    pm=eq_inputs.pm
    Q=eq_inputs.Q
    Time=end_yr-1932
    time_index_spatial_allocation = 1961 - 1932
    Q_input=Qcube_restr(pm,Q,Time,1)
    
    
    #Equilibrium with actual refugees
    ref_shock = DF[1:end-1,:refugee_share_1950];
      
    
    eq_output_Baseline=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        ref_shock,
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    
     #Equilibrium with equalized refugee shares
    Ref = eq_output_Baseline.Population[:,16,1].*eq_output_Baseline.Ref_share[:,16,1];
    Nat = eq_output_Baseline.Population[:,16,1].*(ones(length(ref_shock))-eq_output_Baseline.Ref_share[:,16,1]);
    agg_ref_share = sum(Ref) / (sum(Ref) + sum(Nat)) * ones(length(ref_shock));
   
    
        eq_output_equalized=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        agg_ref_share,
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    
    
        #Equilibrium without refugees    
        eq_output_no_ref=equilibrium_allocation(eq_inputs.pm,eq_inputs.T,eq_inputs.exogV,
        Q_input,eq_inputs.N,eq_inputs.L_I,eq_inputs.L_F,
        zeros(size(DF,1)-1),
        eq_inputs.ag_wages,eq_inputs.manuf_wages,eq_inputs.TradeCosts,
        eq_inputs.MobilityCosts,eq_inputs.Ψ)
    
    #Aggregate GDP 
    agg_gdp_pc_base = sum(eq_output_Baseline.GDPpc.*eq_output_Baseline.Population,dims=1)./sum(eq_output_Baseline.Population,dims=1);
    
    agg_gdp_pc_base = agg_gdp_pc_base[1,:,1]
    
        agg_gdp_pc_equal = sum(eq_output_equalized.GDPpc.*eq_output_equalized.Population,dims=1)./sum(eq_output_equalized.Population,dims=1);
    
    agg_gdp_pc_equal = agg_gdp_pc_equal[1,:,1]
    
            agg_gdp_pc_no = sum(eq_output_no_ref.GDPpc.*eq_output_no_ref.Population,dims=1)./sum(eq_output_no_ref.Population,dims=1);
   agg_gdp_pc_no = agg_gdp_pc_no[1,:,1]
    
    
    agg_pop_base = sum(eq_output_Baseline.Population[:,:,1],dims=1);
    agg_pop_base = agg_pop_base[1,:];
    agg_pop_equal = sum(eq_output_equalized.Population[:,:,1],dims=1);
    agg_pop_equal = agg_pop_equal[1,:];
    agg_pop_no = sum(eq_output_no_ref.Population[:,:,1],dims=1);
    agg_pop_no = agg_pop_no[1,:];
    
    
    # Now create dataframes
    allocation_cf_output=DataFrame(KREIS_ID=DF[1:end-1,:KREIS_ID],
                            countyname=DF[1:end-1,:countyname],
                            state=DF[1:end-1,:state],
        pop1939=DF[1:end-1,:pop_1939],
        sA1933=DF[1:end-1,:sA_1933],
        refugee_share_1950 = DF[1:end-1,:refugee_share_1950]) 
    
    allocation_cf_output.manuf_share_base = eq_output_Baseline.Manuf_share[:,time_index_spatial_allocation,1]
    allocation_cf_output.manuf_share_equal = eq_output_equalized.Manuf_share[:,time_index_spatial_allocation,1]
    allocation_cf_output.manuf_share_no = eq_output_no_ref.Manuf_share[:,time_index_spatial_allocation,1]
    
    allocation_cf_output.y_base = eq_output_Baseline.GDPpc[:,time_index_spatial_allocation,1]
    allocation_cf_output.y_equal = eq_output_equalized.GDPpc[:,time_index_spatial_allocation,1]
    allocation_cf_output.y_no = eq_output_no_ref.GDPpc[:,time_index_spatial_allocation,1]
    
    allocation_cf_output.pop_base = log.(eq_output_Baseline.Population[:,time_index_spatial_allocation,1])
    allocation_cf_output.pop_equal = log.(eq_output_equalized.Population[:,time_index_spatial_allocation,1])
    allocation_cf_output.pop_no = log.(eq_output_no_ref.Population[:,time_index_spatial_allocation,1])
    
    allocation_cf_output.manuf_share_base_LR = eq_output_Baseline.Manuf_share[:,end,1]
    allocation_cf_output.manuf_share_equal_LR = eq_output_equalized.Manuf_share[:,end,1]
    allocation_cf_output.manuf_share_no_LR = eq_output_no_ref.Manuf_share[:,end,1]
    
    allocation_cf_output.y_base_LR = eq_output_Baseline.GDPpc[:,end,1]
    allocation_cf_output.y_equal_LR = eq_output_equalized.GDPpc[:,end,1]
    allocation_cf_output.y_no_LR = eq_output_no_ref.GDPpc[:,end,1]
    
    allocation_cf_output.pop_base_LR = log.(eq_output_Baseline.Population[:,end,1])
    allocation_cf_output.pop_equal_LR = log.(eq_output_equalized.Population[:,end,1])
    allocation_cf_output.pop_no_LR = log.(eq_output_no_ref.Population[:,end,1])
    
    
    allocation_cf_timeseries = DataFrame(year = 1932:end_yr);
    allocation_cf_timeseries.gdp_pc_base = agg_gdp_pc_base;
    allocation_cf_timeseries.gdp_pc_equal = agg_gdp_pc_equal;
    allocation_cf_timeseries.gdp_pc_no  = agg_gdp_pc_no;
    allocation_cf_timeseries.pop_base = agg_pop_base;
    allocation_cf_timeseries.pop_equal = agg_pop_equal;
    allocation_cf_timeseries.pop_no = agg_pop_no;
    
    
    
    CSV.write("$(filename)_space.csv",allocation_cf_output);
    CSV.write("$(filename)_timeseries.csv",allocation_cf_timeseries);
    

end

